Class: PreludeSDK::Models::Intel::KYCMatchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/intel/kyc_match_params.rb,
sig/prelude_sdk/models/intel/kyc_match_params.rbs

Overview

See Also:

  • PreludeSDK::Resources::Intel::KYC#match

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::PreludeSDK

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone:, address: nil, birthdate: nil, country: nil, email: nil, family_name: nil, given_name: nil, locality: nil, postal_code: nil, region: nil, request_options: {}) ⇒ Object

Parameters:

  • phone (String) —

    An E.164 formatted phone number whose subscriber identity to match against.

  • address (String) (defaults to: nil) —

    The street address.

  • birthdate (Date) (defaults to: nil) —

    The date of birth in ISO 8601 (YYYY-MM-DD) format. Compared exactly.

  • country (String) (defaults to: nil) —

    The ISO 3166-1 alpha-2 country code. Compared exactly.

  • email (String) (defaults to: nil) —

    The email address.

  • family_name (String) (defaults to: nil) —

    The end-user's family (last) name.

  • given_name (String) (defaults to: nil) —

    The end-user's given (first) name.

  • locality (String) (defaults to: nil) —

    The locality (city).

  • postal_code (String) (defaults to: nil) —

    The postal code. Compared exactly.

  • region (String) (defaults to: nil) —

    The region, state, or province.

  • request_options (PreludeSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 71

Instance Attribute Details

#address ⇒ String?

The street address.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 21

optional :address, String

#birthdate ⇒ Date?

The date of birth in ISO 8601 (YYYY-MM-DD) format. Compared exactly.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


27
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 27

optional :birthdate, Date

#country ⇒ String?

The ISO 3166-1 alpha-2 country code. Compared exactly.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 33

optional :country, String

#email ⇒ String?

The email address.

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 39

optional :email, String

#family_name ⇒ String?

The end-user's family (last) name.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 45

optional :family_name, String

#given_name ⇒ String?

The end-user's given (first) name.

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 51

optional :given_name, String

#locality ⇒ String?

The locality (city).

Parameters:

  • (String)

Returns:

  • (String, nil)


57
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 57

optional :locality, String

#phone ⇒ String

An E.164 formatted phone number whose subscriber identity to match against.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 15

required :phone, String

#postal_code ⇒ String?

The postal code. Compared exactly.

Parameters:

  • (String)

Returns:

  • (String, nil)


63
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 63

optional :postal_code, String

#region ⇒ String?

The region, state, or province.

Parameters:

  • (String)

Returns:

  • (String, nil)


69
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 69

optional :region, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


75
# File 'sig/prelude_sdk/models/intel/kyc_match_params.rbs', line 75

def to_hash: -> {