Module: PreludeSDK::Models::LookupLookupResponse::LineType

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/lookup_lookup_response.rb,
sig/prelude_sdk/models/lookup_lookup_response.rbs

Overview

The type of phone line.

  • calling_cards - Numbers that are associated with providers of pre-paid domestic and international calling cards.
  • fixed_line - Landline phone numbers.
  • isp - Numbers reserved for Internet Service Providers.
  • local_rate - Numbers that can be assigned non-geographically.
  • mobile - Mobile phone numbers.
  • other - Other types of services.
  • pager - Number ranges specifically allocated to paging devices.
  • payphone - Allocated numbers for payphone kiosks in some countries.
  • premium_rate - Landline numbers where the calling party pays more than standard.
  • satellite - Satellite phone numbers.
  • service - Automated applications.
  • shared_cost - Specific landline ranges where the cost of making the call is shared between the calling and called party.
  • short_codes_commercial - Short codes are memorable, easy-to-use numbers, like the UK's NHS 111, often sold to businesses. Not available in all countries.
  • toll_free - Number where the called party pays for the cost of the call not the calling party.
  • universal_access - Number ranges reserved for Universal Access initiatives.
  • unknown - Unknown phone number type.
  • vpn - Numbers are used exclusively within a private telecommunications network, connecting the operator's terminals internally and not accessible via the public telephone network.
  • voice_mail - A specific category of Interactive Voice Response (IVR) services.
  • voip - Specific ranges for providers of VoIP services to allow incoming calls from the regular telephony network.

See Also:

  • PreludeSDK::Models::LookupLookupResponse#line_type

Constant Summary collapse

CALLING_CARDS =

Returns:

  • (:calling_cards)
:calling_cards
FIXED_LINE =

Returns:

  • (:fixed_line)
:fixed_line
ISP =

Returns:

  • (:isp)
:isp
LOCAL_RATE =

Returns:

  • (:local_rate)
:local_rate
MOBILE =

Returns:

  • (:mobile)
:mobile
OTHER =

Returns:

  • (:other)
:other
PAGER =

Returns:

  • (:pager)
:pager
PAYPHONE =

Returns:

  • (:payphone)
:payphone
PREMIUM_RATE =

Returns:

  • (:premium_rate)
:premium_rate
SATELLITE =

Returns:

  • (:satellite)
:satellite
SERVICE =

Returns:

  • (:service)
:service
SHARED_COST =

Returns:

  • (:shared_cost)
:shared_cost
SHORT_CODES_COMMERCIAL =

Returns:

  • (:short_codes_commercial)
:short_codes_commercial
TOLL_FREE =

Returns:

  • (:toll_free)
:toll_free
UNIVERSAL_ACCESS =

Returns:

  • (:universal_access)
:universal_access
UNKNOWN =

Returns:

  • (:unknown)
:unknown
VPN =

Returns:

  • (:vpn)
:vpn
VOICE_MAIL =

Returns:

  • (:voice_mail)
:voice_mail
VOIP =

Returns:

  • (:voip)
:voip

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[PreludeSDK::Models::LookupLookupResponse::line_type]

Returns:

  • (::Array[PreludeSDK::Models::LookupLookupResponse::line_type])


126
# File 'sig/prelude_sdk/models/lookup_lookup_response.rbs', line 126

def self?.values: -> ::Array[PreludeSDK::Models::LookupLookupResponse::line_type]