Class: PreludeSDK::Models::NotifyGetSubscriptionConfigResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifyGetSubscriptionConfigResponse
- Defined in:
- lib/prelude_sdk/models/notify_get_subscription_config_response.rb
Overview
Defined Under Namespace
Classes: Messages, MoPhoneNumber
Instance Attribute Summary collapse
-
#callback_url ⇒ String
The URL to call when subscription status changes.
-
#created_at ⇒ Time
The date and time when the configuration was created.
-
#id ⇒ String
The subscription configuration ID.
-
#messages ⇒ PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::Messages
The subscription messages configuration.
-
#mo_phone_numbers ⇒ Array<PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::MoPhoneNumber>?
A list of phone numbers for receiving inbound messages.
-
#name ⇒ String
The human-readable name for the subscription configuration.
-
#updated_at ⇒ Time
The date and time when the configuration was last updated.
Instance Method Summary collapse
-
#initialize(help_message: nil, start_message: nil, stop_message: nil) ⇒ Object
constructor
The subscription messages configuration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(help_message: nil, start_message: nil, stop_message: nil) ⇒ Object
The subscription messages configuration.
|
|
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 50
|
Instance Attribute Details
#callback_url ⇒ String
The URL to call when subscription status changes.
17 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 17 required :callback_url, String |
#created_at ⇒ Time
The date and time when the configuration was created.
23 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 23 required :created_at, Time |
#id ⇒ String
The subscription configuration ID.
11 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 11 required :id, String |
#messages ⇒ PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::Messages
The subscription messages configuration.
29 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 29 required :messages, -> { PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::Messages } |
#mo_phone_numbers ⇒ Array<PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::MoPhoneNumber>?
A list of phone numbers for receiving inbound messages.
47 48 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 47 optional :mo_phone_numbers, -> { PreludeSDK::Internal::Type::ArrayOf[PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::MoPhoneNumber] } |
#name ⇒ String
The human-readable name for the subscription configuration.
35 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 35 required :name, String |
#updated_at ⇒ Time
The date and time when the configuration was last updated.
41 |
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 41 required :updated_at, Time |