Class: PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::MoPhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_get_subscription_config_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country_code:, phone_number:) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifyGetSubscriptionConfigResponse::MoPhoneNumber for more details.

Parameters:

  • country_code (String)

    The ISO 3166-1 alpha-2 country code.

  • phone_number (String)

    The phone number in E.164 format for long codes, or short code format for short



# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 109

Instance Attribute Details

#country_codeString

The ISO 3166-1 alpha-2 country code.

Returns:

  • (String)


100
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 100

required :country_code, String

#phone_numberString

The phone number in E.164 format for long codes, or short code format for short codes.

Returns:

  • (String)


107
# File 'lib/prelude_sdk/models/notify_get_subscription_config_response.rb', line 107

required :phone_number, String