Class: PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse
- Defined in:
- lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#config_id ⇒ String
The subscription configuration ID.
-
#phone_number ⇒ String
The phone number in E.164 format.
-
#reason ⇒ String?
Additional context about the state change (e.g., the keyword that was sent).
-
#source ⇒ Symbol, PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse::Source
How the subscription state was changed:.
-
#state ⇒ Symbol, PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse::State
The subscription state:.
-
#updated_at ⇒ Time
The date and time when the subscription status was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(config_id:, phone_number:, source:, state:, updated_at:, reason: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NotifyGetSubscriptionPhoneNumberResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(config_id:, phone_number:, source:, state:, updated_at:, reason: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse for more details.
|
|
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 51
|
Instance Attribute Details
#config_id ⇒ String
The subscription configuration ID.
11 |
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 11 required :config_id, String |
#phone_number ⇒ String
The phone number in E.164 format.
17 |
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 17 required :phone_number, String |
#reason ⇒ String?
Additional context about the state change (e.g., the keyword that was sent).
49 |
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 49 optional :reason, String |
#source ⇒ Symbol, PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse::Source
How the subscription state was changed:
-
‘MO_KEYWORD` - User sent a keyword (STOP/START)
-
‘API` - Changed via API
-
‘CSV_IMPORT` - Imported from CSV
-
‘CARRIER_DISCONNECT` - Automatically unsubscribed due to carrier disconnect
28 |
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 28 required :source, enum: -> { PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse::Source } |
#state ⇒ Symbol, PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse::State
The subscription state:
-
‘SUB` - Subscribed (user can receive marketing messages)
-
‘UNSUB` - Unsubscribed (user has opted out)
37 |
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 37 required :state, enum: -> { PreludeSDK::Models::NotifyGetSubscriptionPhoneNumberResponse::State } |
#updated_at ⇒ Time
The date and time when the subscription status was last updated.
43 |
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 43 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/notify_get_subscription_phone_number_response.rb', line 83
|