Class: PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_list_subscription_configs_response.rb

Defined Under Namespace

Classes: Messages, MoPhoneNumber

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(help_message: nil, start_message: nil, stop_message: nil) ⇒ Object

The subscription messages configuration.

Parameters:

  • help_message (String) (defaults to: nil)

    Message sent when user requests help.

  • start_message (String) (defaults to: nil)

    Message sent when user subscribes.

  • stop_message (String) (defaults to: nil)

    Message sent when user unsubscribes.



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 29

class Config < PreludeSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The subscription configuration ID.
  #
  #   @return [String]
  required :id, String

  # @!attribute callback_url
  #   The URL to call when subscription status changes.
  #
  #   @return [String]
  required :callback_url, String

  # @!attribute created_at
  #   The date and time when the configuration was created.
  #
  #   @return [Time]
  required :created_at, Time

  # @!attribute messages
  #   The subscription messages configuration.
  #
  #   @return [PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::Messages]
  required :messages, -> { PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::Messages }

  # @!attribute name
  #   The human-readable name for the subscription configuration.
  #
  #   @return [String]
  required :name, String

  # @!attribute updated_at
  #   The date and time when the configuration was last updated.
  #
  #   @return [Time]
  required :updated_at, Time

  # @!attribute mo_phone_numbers
  #   A list of phone numbers for receiving inbound messages.
  #
  #   @return [Array<PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber>, nil]
  optional :mo_phone_numbers,
           -> { PreludeSDK::Internal::Type::ArrayOf[PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber] }

  # @!method initialize(id:, callback_url:, created_at:, messages:, name:, updated_at:, mo_phone_numbers: nil)
  #   @param id [String] The subscription configuration ID.
  #
  #   @param callback_url [String] The URL to call when subscription status changes.
  #
  #   @param created_at [Time] The date and time when the configuration was created.
  #
  #   @param messages [PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::Messages] The subscription messages configuration.
  #
  #   @param name [String] The human-readable name for the subscription configuration.
  #
  #   @param updated_at [Time] The date and time when the configuration was last updated.
  #
  #   @param mo_phone_numbers [Array<PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber>] A list of phone numbers for receiving inbound messages.

  # @see PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config#messages
  class Messages < PreludeSDK::Internal::Type::BaseModel
    # @!attribute help_message
    #   Message sent when user requests help.
    #
    #   @return [String, nil]
    optional :help_message, String

    # @!attribute start_message
    #   Message sent when user subscribes.
    #
    #   @return [String, nil]
    optional :start_message, String

    # @!attribute stop_message
    #   Message sent when user unsubscribes.
    #
    #   @return [String, nil]
    optional :stop_message, String

    # @!method initialize(help_message: nil, start_message: nil, stop_message: nil)
    #   The subscription messages configuration.
    #
    #   @param help_message [String] Message sent when user requests help.
    #
    #   @param start_message [String] Message sent when user subscribes.
    #
    #   @param stop_message [String] Message sent when user unsubscribes.
  end

  class MoPhoneNumber < PreludeSDK::Internal::Type::BaseModel
    # @!attribute country_code
    #   The ISO 3166-1 alpha-2 country code.
    #
    #   @return [String]
    required :country_code, String

    # @!attribute phone_number
    #   The phone number in E.164 format for long codes, or short code format for short
    #   codes.
    #
    #   @return [String]
    required :phone_number, String

    # @!method initialize(country_code:, phone_number:)
    #   Some parameter documentations has been truncated, see
    #   {PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber}
    #   for more details.
    #
    #   @param country_code [String] The ISO 3166-1 alpha-2 country code.
    #
    #   @param phone_number [String] The phone number in E.164 format for long codes, or short code format for short
  end
end

Instance Attribute Details

#callback_urlString

The URL to call when subscription status changes.

Returns:

  • (String)


40
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 40

required :callback_url, String

#created_atTime

The date and time when the configuration was created.

Returns:

  • (Time)


46
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 46

required :created_at, Time

#idString

The subscription configuration ID.

Returns:

  • (String)


34
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 34

required :id, String

#messagesPreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::Messages

The subscription messages configuration.



52
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 52

required :messages, -> { PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::Messages }

#mo_phone_numbersArray<PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber>?

A list of phone numbers for receiving inbound messages.



70
71
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 70

optional :mo_phone_numbers,
-> { PreludeSDK::Internal::Type::ArrayOf[PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber] }

#nameString

The human-readable name for the subscription configuration.

Returns:

  • (String)


58
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 58

required :name, String

#updated_atTime

The date and time when the configuration was last updated.

Returns:

  • (Time)


64
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 64

required :updated_at, Time