Class: PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_list_subscription_configs_response.rb,
sig/prelude_sdk/models/notify_list_subscription_configs_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country_code:, phone_number:) ⇒ MoPhoneNumber

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifyListSubscriptionConfigsResponse::Config::MoPhoneNumber for more details.

Parameters:

  • country_code (String)

    The ISO 3166-1 alpha-2 country code.

  • phone_number (String)

    The phone number in E.164 format for long codes, or short code format for short

  • country_code: (String)
  • phone_number: (String)


# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 132

Instance Attribute Details

#country_codeString

The ISO 3166-1 alpha-2 country code.

Parameters:

  • value (String)

Returns:

  • (String)


123
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 123

required :country_code, String

#phone_numberString

The phone number in E.164 format for long codes, or short code format for short codes.

Parameters:

  • value (String)

Returns:

  • (String)


130
# File 'lib/prelude_sdk/models/notify_list_subscription_configs_response.rb', line 130

required :phone_number, String

Instance Method Details

#to_hash{ country_code: String, phone_number: String }

Returns:

  • ({ country_code: String, phone_number: String })


114
# File 'sig/prelude_sdk/models/notify_list_subscription_configs_response.rbs', line 114

def to_hash: -> { country_code: String, phone_number: String }