Class: PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/notify_list_subscription_phone_numbers_params.rb
Overview
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
- #config_id ⇒ String
-
#cursor ⇒ String?
Pagination cursor from the previous response.
-
#limit ⇒ Integer?
Maximum number of phone numbers to return per page.
-
#state ⇒ Symbol, ...
Filter by subscription state.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(config_id:, cursor: nil, limit: nil, state: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(config_id:, cursor: nil, limit: nil, state: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_params.rb', line 33
|
Instance Attribute Details
#config_id ⇒ String
13 |
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_params.rb', line 13 required :config_id, String |
#cursor ⇒ String?
Pagination cursor from the previous response
19 |
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_params.rb', line 19 optional :cursor, String |
#limit ⇒ Integer?
Maximum number of phone numbers to return per page
25 |
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_params.rb', line 25 optional :limit, Integer |
#state ⇒ Symbol, ...
Filter by subscription state
31 |
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_params.rb', line 31 optional :state, enum: -> { PreludeSDK::NotifyListSubscriptionPhoneNumbersParams::State } |