Class: PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersResponse
- Defined in:
- lib/prelude_sdk/models/notify_list_subscription_phone_numbers_response.rb
Overview
Defined Under Namespace
Classes: PhoneNumber
Instance Attribute Summary collapse
-
#next_cursor ⇒ String?
Pagination cursor for the next page of results.
-
#phone_numbers ⇒ Array<PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersResponse::PhoneNumber>
A list of phone numbers and their subscription statuses.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from PreludeSDK::Internal::Type::BaseModel
Instance Attribute Details
#next_cursor ⇒ String?
Pagination cursor for the next page of results. Omitted if there are no more pages.
19 |
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_response.rb', line 19 optional :next_cursor, String |
#phone_numbers ⇒ Array<PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersResponse::PhoneNumber>
A list of phone numbers and their subscription statuses.
11 12 |
# File 'lib/prelude_sdk/models/notify_list_subscription_phone_numbers_response.rb', line 11 required :phone_numbers, -> { PreludeSDK::Internal::Type::ArrayOf[PreludeSDK::Models::NotifyListSubscriptionPhoneNumbersResponse::PhoneNumber] } |