Class: PreludeSDK::Models::NotifyReplyParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/notify_reply_params.rb,
sig/prelude_sdk/models/notify_reply_params.rbs

Overview

See Also:

  • PreludeSDK::Resources::Notify#reply

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::PreludeSDK

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(reply_to:, text:, to:, callback_url: nil, correlation_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifyReplyParams for more details.

Parameters:

  • reply_to (String) —

    The inbound message ID (prefixed with im_) to reply to. This ID is provided in

  • text (String) —

    The reply message body sent as a free-form WhatsApp text.

  • to (String) —

    The recipient's phone number in E.164 format. Must match the phone number that s

  • callback_url (String) (defaults to: nil) —

    The URL where webhooks will be sent for delivery events of this reply.

  • correlation_id (String) (defaults to: nil) —

    A user-defined identifier to correlate this reply with your internal systems. It

  • request_options (PreludeSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 43

Instance Attribute Details

#callback_url ⇒ String?

The URL where webhooks will be sent for delivery events of this reply.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 34

optional :callback_url, String

#correlation_id ⇒ String?

A user-defined identifier to correlate this reply with your internal systems. It is returned in the response and any webhook events that refer to this message.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 41

optional :correlation_id, String

#reply_to ⇒ String

The inbound message ID (prefixed with im_) to reply to. This ID is provided in the inbound.message.received webhook event.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 15

required :reply_to, String

#text ⇒ String

The reply message body sent as a free-form WhatsApp text.

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 21

required :text, String

#to ⇒ String

The recipient's phone number in E.164 format. Must match the phone number that sent the original inbound message.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 28

required :to, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


40
# File 'sig/prelude_sdk/models/notify_reply_params.rbs', line 40

def to_hash: -> {