Class: PreludeSDK::Models::NotifySendBatchResponse::Result::Message

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_send_batch_response.rb,
sig/prelude_sdk/models/notify_send_batch_response.rbs

Overview

See Also:

  • PreludeSDK::Models::NotifySendBatchResponse::Result#message

Defined Under Namespace

Modules: Encoding

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, correlation_id: nil, created_at: nil, encoding: nil, estimated_segment_count: nil, expires_at: nil, from: nil, locale: nil, schedule_at: nil, to: nil) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifySendBatchResponse::Result::Message for more details.

Present only if success is true.

Parameters:

  • (defaults to: nil)

    The message identifier.

  • (defaults to: nil)

    The correlation identifier for the message.

  • (defaults to: nil)

    The message creation date in RFC3339 format.

  • (defaults to: nil)

    The SMS encoding type based on message content. GSM-7 supports standard characte

  • (defaults to: nil)

    The estimated number of SMS segments for this message. This value is not contrac

  • (defaults to: nil)

    The message expiration date in RFC3339 format.

  • (defaults to: nil)

    The Sender ID used for this message.

  • (defaults to: nil)

    The locale used for the message, if any.

  • (defaults to: nil)

    When the message will actually be sent in RFC3339 format with timezone offset.

  • (defaults to: nil)

    The recipient's phone number in E.164 format.



# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 195

Instance Attribute Details

#correlation_id ⇒ String?

The correlation identifier for the message.

Parameters:

Returns:



141
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 141

optional :correlation_id, String

#created_at ⇒ Time?

The message creation date in RFC3339 format.

Parameters:

Returns:



147
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 147

optional :created_at, Time

#encoding ⇒ Symbol, ...

The SMS encoding type based on message content. GSM-7 supports standard characters (up to 160 chars per segment), while UCS-2 supports Unicode including emoji (up to 70 chars per segment). Only present for SMS messages.

Returns:



155
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 155

optional :encoding, enum: -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Message::Encoding }

#estimated_segment_count ⇒ Integer?

The estimated number of SMS segments for this message. This value is not contractual; the actual segment count will be determined after the SMS is sent by the provider. Only present for SMS messages.

Parameters:

Returns:



163
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 163

optional :estimated_segment_count, Integer

#expires_at ⇒ Time?

The message expiration date in RFC3339 format.

Parameters:

Returns:



169
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 169

optional :expires_at, Time

#from ⇒ String?

The Sender ID used for this message.

Parameters:

Returns:



175
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 175

optional :from, String

#id ⇒ String?

The message identifier.

Parameters:

Returns:



135
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 135

optional :id, String

#locale ⇒ String?

The locale used for the message, if any.

Parameters:

Returns:



181
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 181

optional :locale, String

#schedule_at ⇒ Time?

When the message will actually be sent in RFC3339 format with timezone offset.

Parameters:

Returns:



187
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 187

optional :schedule_at, Time

#to ⇒ String?

The recipient's phone number in E.164 format.

Parameters:

Returns:



193
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 193

optional :to, String

Instance Method Details

#to_hash ⇒ {

Returns:



187
# File 'sig/prelude_sdk/models/notify_send_batch_response.rbs', line 187

def to_hash: -> {