Class: PreludeSDK::Models::NotifySendParams::Context

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_send_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(template_id:, to:, callback_url: nil, context: nil, correlation_id: nil, document: nil, expires_at: nil, from: nil, locale: nil, preferred_channel: nil, schedule_at: nil, text: nil, variables: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifySendParams for more details.

Parameters:

  • template_id (String)

    The template identifier configured by your Customer Success team.

  • to (String)

    The recipient’s phone number in E.164 format.

  • callback_url (String) (defaults to: nil)

    The URL where webhooks will be sent for message delivery events.

  • context (PreludeSDK::Models::NotifySendParams::Context) (defaults to: nil)

    Context for replying to an inbound message. When provided, the message is sent a

  • correlation_id (String) (defaults to: nil)

    A user-defined identifier to correlate this message with your internal systems.

  • document (PreludeSDK::Models::NotifySendParams::Document) (defaults to: nil)

    A media attachment to include in the message header. Supported on

  • expires_at (Time) (defaults to: nil)

    The message expiration date in RFC3339 format. The message will not be sent if t

  • from (String) (defaults to: nil)

    The Sender ID. Must be approved for your account.

  • locale (String) (defaults to: nil)

    A BCP-47 formatted locale string with the language the text message will be sent

  • preferred_channel (Symbol, PreludeSDK::Models::NotifySendParams::PreferredChannel) (defaults to: nil)

    The preferred channel to be used in priority for message delivery. If the channe

  • schedule_at (Time) (defaults to: nil)

    Schedule the message for future delivery in RFC3339 format. Marketing messages c

  • text (String) (defaults to: nil)

    The reply message body. Required when ‘context.reply_to` is provided. Used for 2

  • variables (Hash{Symbol=>String}) (defaults to: nil)

    The variables to be replaced in the template.

  • request_options (PreludeSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 141

class Context < PreludeSDK::Internal::Type::BaseModel
  # @!attribute reply_to
  #   The inbound message ID (prefixed with `im_`) to reply to. This ID is provided in
  #   the `inbound.message.received` webhook event.
  #
  #   @return [String]
  required :reply_to, String

  # @!method initialize(reply_to:)
  #   Some parameter documentations has been truncated, see
  #   {PreludeSDK::Models::NotifySendParams::Context} for more details.
  #
  #   Context for replying to an inbound message. When provided, the message is sent
  #   as a WhatsApp reply within the 24-hour conversation window.
  #
  #   @param reply_to [String] The inbound message ID (prefixed with `im_`) to reply to. This ID is provided in
end

Instance Attribute Details

#reply_toString

The inbound message ID (prefixed with ‘im_`) to reply to. This ID is provided in the `inbound.message.received` webhook event.

Returns:

  • (String)


147
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 147

required :reply_to, String