Module: PreludeSDK::Models::NotifySendParams::PreferredChannel

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/notify_send_params.rb,
sig/prelude_sdk/models/notify_send_params.rbs

Overview

The preferred channel to be used in priority for message delivery. If the channel is unavailable, the system will fallback to other available channels.

Constant Summary collapse

SMS =

Returns:

  • (:sms)
:sms
RCS =

Returns:

  • (:rcs)
:rcs
WHATSAPP =

Returns:

  • (:whatsapp)
:whatsapp

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/prelude_sdk/models/notify_send_params.rb', line 179

Instance Method Details

#self?.values::Array[PreludeSDK::Models::NotifySendParams::preferred_channel]

Returns:

  • (::Array[PreludeSDK::Models::NotifySendParams::preferred_channel])


127
# File 'sig/prelude_sdk/models/notify_send_params.rbs', line 127

def self?.values: -> ::Array[PreludeSDK::Models::NotifySendParams::preferred_channel]