Class: PreludeSDK::Models::NotifySendResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_send_response.rb

Overview

Defined Under Namespace

Modules: Encoding

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, expires_at:, template_id:, to:, variables:, callback_url: nil, correlation_id: nil, encoding: nil, estimated_segment_count: nil, from: nil, schedule_at: nil) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifySendResponse for more details.

Parameters:

  • id (String)

    The message identifier.

  • created_at (Time)

    The message creation date in RFC3339 format.

  • expires_at (Time)

    The message expiration date in RFC3339 format.

  • template_id (String)

    The template identifier.

  • to (String)

    The recipient’s phone number in E.164 format.

  • variables (Hash{Symbol=>String})

    The variables to be replaced in the template.

  • callback_url (String) (defaults to: nil)

    The callback URL where webhooks will be sent.

  • correlation_id (String) (defaults to: nil)

    A user-defined identifier to correlate this message with your internal systems.

  • encoding (Symbol, PreludeSDK::Models::NotifySendResponse::Encoding) (defaults to: nil)

    The SMS encoding type based on message content. GSM-7 supports standard characte

  • estimated_segment_count (Integer) (defaults to: nil)

    The estimated number of SMS segments for this message. This value is not contrac

  • from (String) (defaults to: nil)

    The Sender ID used for this message.

  • schedule_at (Time) (defaults to: nil)

    When the message will actually be sent in RFC3339 format with timezone offset. F



# File 'lib/prelude_sdk/models/notify_send_response.rb', line 85

Instance Attribute Details

#callback_urlString?

The callback URL where webhooks will be sent.

Returns:

  • (String, nil)


47
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 47

optional :callback_url, String

#correlation_idString?

A user-defined identifier to correlate this message with your internal systems.

Returns:

  • (String, nil)


53
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 53

optional :correlation_id, String

#created_atTime

The message creation date in RFC3339 format.

Returns:

  • (Time)


17
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 17

required :created_at, Time

#encodingSymbol, ...

The SMS encoding type based on message content. GSM-7 supports standard characters (up to 160 chars per segment), while UCS-2 supports Unicode including emoji (up to 70 chars per segment). Only present for SMS messages.



61
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 61

optional :encoding, enum: -> { PreludeSDK::Models::NotifySendResponse::Encoding }

#estimated_segment_countInteger?

The estimated number of SMS segments for this message. This value is not contractual; the actual segment count will be determined after the SMS is sent by the provider. Only present for SMS messages.

Returns:

  • (Integer, nil)


69
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 69

optional :estimated_segment_count, Integer

#expires_atTime

The message expiration date in RFC3339 format.

Returns:

  • (Time)


23
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 23

required :expires_at, Time

#fromString?

The Sender ID used for this message.

Returns:

  • (String, nil)


75
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 75

optional :from, String

#idString

The message identifier.

Returns:

  • (String)


11
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 11

required :id, String

#schedule_atTime?

When the message will actually be sent in RFC3339 format with timezone offset. For marketing messages, this may differ from the requested schedule_at due to automatic compliance adjustments.

Returns:

  • (Time, nil)


83
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 83

optional :schedule_at, Time

#template_idString

The template identifier.

Returns:

  • (String)


29
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 29

required :template_id, String

#toString

The recipient’s phone number in E.164 format.

Returns:

  • (String)


35
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 35

required :to, String

#variablesHash{Symbol=>String}

The variables to be replaced in the template.

Returns:

  • (Hash{Symbol=>String})


41
# File 'lib/prelude_sdk/models/notify_send_response.rb', line 41

required :variables, PreludeSDK::Internal::Type::HashOf[String]