Module: PreludeSDK::Models::TransactionalSendParams::PreferredChannel

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/transactional_send_params.rb

Overview

The preferred delivery channel for the message. When specified, the system will prioritize sending via the requested channel if the template is configured for it.

If not specified and the template is configured for WhatsApp, the message will be sent via WhatsApp first, with automatic fallback to SMS if WhatsApp delivery is unavailable.

Supported channels: ‘sms`, `rcs`, `whatsapp`.

Constant Summary collapse

SMS =
:sms
RCS =
:rcs
WHATSAPP =
:whatsapp

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 170