Module: PreludeSDK::Models::Verification::Phone::HistoryListParams::Channel

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/verification/phone/history_list_params.rb,
sig/prelude_sdk/models/verification/phone/history_list_params.rbs

Constant Summary collapse

SMS =

Returns:

  • (:sms)
:sms
RCS =

Returns:

  • (:rcs)
:rcs
WHATSAPP =

Returns:

  • (:whatsapp)
:whatsapp
VIBER =

Returns:

  • (:viber)
:viber
ZALO =

Returns:

  • (:zalo)
:zalo
TELEGRAM =

Returns:

  • (:telegram)
:telegram
VOICE =

Returns:

  • (:voice)
:voice
SILENT =

Returns:

  • (:silent)
:silent

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(channels: nil, cursor: nil, device_platform: nil, from: nil, limit: nil, max_attempts: nil, min_attempts: nil, phone_number: nil, region: nil, status: nil, template_id: nil, to: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::Verification::Phone::HistoryListParams for more details.

Parameters:

  • channels (Array<Symbol, PreludeSDK::Models::Verification::Phone::HistoryListParams::Channel>) (defaults to: nil) —

    Only verifications that could use one of these channels. Repeat the parameter fo

  • cursor (String) (defaults to: nil) —

    Pagination cursor from the previous response.

  • device_platform (Symbol, PreludeSDK::Models::Verification::Phone::HistoryListParams::DevicePlatform) (defaults to: nil) —

    Only verifications created from this device platform.

  • from (Time) (defaults to: nil) —

    Only verifications created at or after this RFC 3339 timestamp. Goes with to,

  • limit (Integer) (defaults to: nil) —

    Maximum number of verifications to return per page.

  • max_attempts (Integer) (defaults to: nil) —

    Only verifications that sent at most this many messages. 0 keeps the verificat

  • min_attempts (Integer) (defaults to: nil) —

    Only verifications that sent at least this many messages.

  • phone_number (String) (defaults to: nil) —

    Only verifications targeting this E.164 phone number. The leading + may be omi

  • region (String) (defaults to: nil) —

    Only verifications of phone numbers from this region, as an ISO 3166-1 alpha-2 c

  • status (Symbol, PreludeSDK::Models::Verification::Phone::HistoryListParams::Status) (defaults to: nil) —

    Only verifications in this status. pending_check cannot be filtered on.

  • template_id (String) (defaults to: nil) —

    Only verifications sent with this template, as returned in template_id by [Get

  • to (Time) (defaults to: nil) —

    Only verifications created at or before this RFC 3339 timestamp. Goes with `from

  • request_options (PreludeSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 123

module Channel
  extend PreludeSDK::Internal::Type::Enum

  SMS = :sms
  RCS = :rcs
  WHATSAPP = :whatsapp
  VIBER = :viber
  ZALO = :zalo
  TELEGRAM = :telegram
  VOICE = :voice
  SILENT = :silent

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values ⇒ ::Array[PreludeSDK::Models::Verification::Phone::HistoryListParams::channel]

Returns:

  • (::Array[PreludeSDK::Models::Verification::Phone::HistoryListParams::channel])


134
# File 'sig/prelude_sdk/models/verification/phone/history_list_params.rbs', line 134

def self?.values: -> ::Array[PreludeSDK::Models::Verification::Phone::HistoryListParams::channel]