Class: PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb,
sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs

Overview

See Also:

  • PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse#lifecycle

Defined Under Namespace

Classes: Event

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



269
# File 'sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs', line 269

def initialize: (

Instance Attribute Details

#events ⇒ Array<PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event>



312
313
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 312

required :events,
-> { PreludeSDK::Internal::Type::ArrayOf[PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event] }

#total_cost ⇒ PreludeSDK::Models::Verification::Phone::PhoneVerificationMoney?



318
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 318

optional :total_cost, -> { PreludeSDK::Verification::Phone::PhoneVerificationMoney }

#undeliverable_route_count ⇒ Integer?

How many times the message was reported undeliverable by independent routes. Above zero usually means the phone number is incorrect or the device unreachable.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


326
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 326

optional :undeliverable_route_count, Integer

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


275
# File 'sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs', line 275

def to_hash: -> {