Class: PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Signals
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Signals
- Defined in:
- lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb,
sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs
Overview
Instance Attribute Summary collapse
-
#device_id ⇒ String?
End-user device identifier you forwarded.
-
#is_trusted_user ⇒ Boolean
Whether you flagged this end user as trusted when creating the verification.
-
#ja4_fingerprint ⇒ String?
TLS fingerprint you forwarded.
- #os_version ⇒ String?
- #user_agent ⇒ String?
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
842 |
# File 'sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs', line 842
def initialize: (
|
Instance Attribute Details
#device_id ⇒ String?
End-user device identifier you forwarded.
838 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 838 optional :device_id, String |
#is_trusted_user ⇒ Boolean
Whether you flagged this end user as trusted when creating the verification. Declared by you, not computed by Prelude.
832 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 832 required :is_trusted_user, PreludeSDK::Internal::Type::Boolean |
#ja4_fingerprint ⇒ String?
TLS fingerprint you forwarded.
844 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 844 optional :ja4_fingerprint, String |
#os_version ⇒ String?
849 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 849 optional :os_version, String |
#user_agent ⇒ String?
854 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 854 optional :user_agent, String |
Instance Method Details
#to_hash ⇒ {
850 |
# File 'sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs', line 850
def to_hash: -> {
|