Module: PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb,
sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs

Overview

The outcome of the verification.

  • converted - The end user submitted a valid code.
  • not_converted - The verification expired without a valid code.
  • pending_check - A code was delivered and Prelude is still waiting for a check.
  • sent - A code was sent and the verification window is still open.
  • challenged - The verification was restricted to non-SMS and non-voice channels.
  • suspected_fraud - The anti-fraud system blocked the verification.
  • in_blocklist - The phone number is on the configured block list.
  • invalid_line - The phone number is not a valid line type.
  • invalid_number - The phone number is not a valid number.
  • rate_limited - The verification was refused by a rate limit.
  • expired_signals - The SDK signals were collected too long before the request.
  • shadowed - The anti-fraud system flagged the verification without blocking it.

See Also:

  • PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse#status

Constant Summary collapse

CONVERTED =

Returns:

  • (:converted)
:converted
NOT_CONVERTED =

Returns:

  • (:not_converted)
:not_converted
PENDING_CHECK =

Returns:

  • (:pending_check)
:pending_check
SENT =

Returns:

  • (:sent)
:sent
CHALLENGED =

Returns:

  • (:challenged)
:challenged
SUSPECTED_FRAUD =

Returns:

  • (:suspected_fraud)
:suspected_fraud
IN_BLOCKLIST =

Returns:

  • (:in_blocklist)
:in_blocklist
INVALID_LINE =

Returns:

  • (:invalid_line)
:invalid_line
INVALID_NUMBER =

Returns:

  • (:invalid_number)
:invalid_number
RATE_LIMITED =

Returns:

  • (:rate_limited)
:rate_limited
EXPIRED_SIGNALS =

Returns:

  • (:expired_signals)
:expired_signals
SHADOWED =

Returns:

  • (:shadowed)
:shadowed

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::status]

Returns:

  • (::Array[PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::status])


199
# File 'sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs', line 199

def self?.values: -> ::Array[PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::status]