Class: PreludeSDK::Models::VerificationCheckParams::Target

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/verification_check_params.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, value:) ⇒ Object

The verification target. Either a phone number or an email address. To use the email verification feature contact us to discuss your use case.

Parameters:



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 33

class Target < PreludeSDK::Internal::Type::BaseModel
  # @!attribute type
  #   The type of the target. Either "phone_number" or "email_address".
  #
  #   @return [Symbol, PreludeSDK::Models::VerificationCheckParams::Target::Type]
  required :type, enum: -> { PreludeSDK::VerificationCheckParams::Target::Type }

  # @!attribute value
  #   An E.164 formatted phone number or an email address.
  #
  #   @return [String]
  required :value, String

  # @!method initialize(type:, value:)
  #   The verification target. Either a phone number or an email address. To use the
  #   email verification feature contact us to discuss your use case.
  #
  #   @param type [Symbol, PreludeSDK::Models::VerificationCheckParams::Target::Type] The type of the target. Either "phone_number" or "email_address".
  #
  #   @param value [String] An E.164 formatted phone number or an email address.

  # The type of the target. Either "phone_number" or "email_address".
  #
  # @see PreludeSDK::Models::VerificationCheckParams::Target#type
  module Type
    extend PreludeSDK::Internal::Type::Enum

    PHONE_NUMBER = :phone_number
    EMAIL_ADDRESS = :email_address

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#typeSymbol, PreludeSDK::Models::VerificationCheckParams::Target::Type

The type of the target. Either “phone_number” or “email_address”.



38
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 38

required :type, enum: -> { PreludeSDK::VerificationCheckParams::Target::Type }

#valueString

An E.164 formatted phone number or an email address.

Returns:

  • (String)


44
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 44

required :value, String