Class: PreludeSDK::Models::VerificationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/verification_create_params.rb

Overview

Defined Under Namespace

Classes: Metadata, Options, Signals, Target

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(correlation_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Metadata for more details.

The metadata for this verification. This object will be returned with every response or webhook sent that refers to this verification.

Parameters:

  • correlation_id (String) (defaults to: nil)

    A user-defined identifier to correlate this verification with. It is returned in



# File 'lib/prelude_sdk/models/verification_create_params.rb', line 102

Instance Attribute Details

#dispatch_idString?

The identifier of the dispatch that came from the front-end SDK.

Returns:

  • (String, nil)


21
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 21

optional :dispatch_id, String

#metadataPreludeSDK::Models::VerificationCreateParams::Metadata?

The metadata for this verification. This object will be returned with every response or webhook sent that refers to this verification.



28
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 28

optional :metadata, -> { PreludeSDK::VerificationCreateParams::Metadata }

#optionsPreludeSDK::Models::VerificationCreateParams::Options?

Verification options



34
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 34

optional :options, -> { PreludeSDK::VerificationCreateParams::Options }

#signalsPreludeSDK::Models::VerificationCreateParams::Signals?

The signals used for anti-fraud. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).



41
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 41

optional :signals, -> { PreludeSDK::VerificationCreateParams::Signals }

#targetPreludeSDK::Models::VerificationCreateParams::Target

The verification target. Either a phone number or an email address. To use the email verification feature contact us to discuss your use case.



15
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 15

required :target, -> { PreludeSDK::VerificationCreateParams::Target }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/prelude_sdk/models/verification_create_params.rb', line 89