Module: PreludeSDK::Models::VerificationCreateParams::Options::Method
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/prelude_sdk/models/verification_create_params.rb,
sig/prelude_sdk/models/verification_create_params.rbs
Overview
The method used for verifying this phone number. The 'voice' option provides an accessible alternative for visually impaired users by delivering the verification code through a phone call rather than a text message. It also allows verification of landline numbers that cannot receive SMS messages. The 'message' option explicitly requests message delivery (SMS, WhatsApp ...) and skips silent verification, useful for scenarios requiring direct user interaction.
Constant Summary collapse
- AUTO =
:auto- VOICE =
:voice- MESSAGE =
:message
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[PreludeSDK::Models::VerificationCreateParams::Options::method_]
271 |
# File 'sig/prelude_sdk/models/verification_create_params.rbs', line 271
def self?.values: -> ::Array[PreludeSDK::Models::VerificationCreateParams::Options::method_]
|