Module: PreludeSDK::Models::VerificationCreateParams::Options::PreferredChannel

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/verification_create_params.rb,
sig/prelude_sdk/models/verification_create_params.rbs

Overview

The channel to prioritize when delivering the verification. Prelude prioritizes this channel on the first attempt and continues to prefer it on retries while an untried route on that channel remains; once those are exhausted, retries fall back to the next best available route. If the channel is unavailable (for example, when a verification is challenged), Prelude uses the best available route instead. Cannot be combined with channels.

See Also:

  • PreludeSDK::Models::VerificationCreateParams::Options#preferred_channel

Constant Summary collapse

SMS =

Returns:

  • (:sms)
:sms
RCS =

Returns:

  • (:rcs)
:rcs
WHATSAPP =

Returns:

  • (:whatsapp)
:whatsapp
VIBER =

Returns:

  • (:viber)
:viber
ZALO =

Returns:

  • (:zalo)
:zalo
TELEGRAM =

Returns:

  • (:telegram)
:telegram

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/prelude_sdk/models/verification_create_params.rb', line 341

Instance Method Details

#self?.values ⇒ ::Array[PreludeSDK::Models::VerificationCreateParams::Options::preferred_channel]

Returns:

  • (::Array[PreludeSDK::Models::VerificationCreateParams::Options::preferred_channel])


252
# File 'sig/prelude_sdk/models/verification_create_params.rbs', line 252

def self?.values: -> ::Array[PreludeSDK::Models::VerificationCreateParams::Options::preferred_channel]