Class: PreludeSDK::Models::VerificationManagement::SandboxAddPhoneNumberParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationManagement::SandboxAddPhoneNumberParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_params.rb,
sig/prelude_sdk/models/verification_management/sandbox_add_phone_number_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::PreludeSDK
Instance Attribute Summary collapse
-
#attempt_code ⇒ String
The fixed attempt code that will validate verification attempts for this phone number.
-
#phone_number ⇒ String
An E.164 formatted phone number to add to the sandbox list.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(attempt_code:, phone_number:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SandboxAddPhoneNumberParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attempt_code:, phone_number:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationManagement::SandboxAddPhoneNumberParams for more details.
|
|
# File 'lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_params.rb', line 24
|
Instance Attribute Details
#attempt_code ⇒ String
The fixed attempt code that will validate verification attempts for this phone number.
16 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_params.rb', line 16 required :attempt_code, String |
#phone_number ⇒ String
An E.164 formatted phone number to add to the sandbox list.
22 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_params.rb', line 22 required :phone_number, String |
Instance Method Details
#to_hash ⇒ {
22 |
# File 'sig/prelude_sdk/models/verification_management/sandbox_add_phone_number_params.rbs', line 22
def to_hash: -> {
|