Class: PreludeSDK::Models::VerificationManagement::SandboxListPhoneNumbersResponse::PhoneNumber
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationManagement::SandboxListPhoneNumbersResponse::PhoneNumber
- Defined in:
- lib/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rb,
sig/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rbs
Instance Attribute Summary collapse
-
#attempt_code ⇒ String
The fixed attempt code associated with the sandbox phone number.
-
#created_at ⇒ Time
The date and time when the phone number was added to the sandbox list.
-
#phone_number ⇒ String
An E.164 formatted phone number.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attempt_code:, created_at:, phone_number:) ⇒ Object
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rb', line 18 class PhoneNumber < PreludeSDK::Internal::Type::BaseModel # @!attribute attempt_code # The fixed attempt code associated with the sandbox phone number. # # @return [String] required :attempt_code, String # @!attribute created_at # The date and time when the phone number was added to the sandbox list. # # @return [Time] required :created_at, Time # @!attribute phone_number # An E.164 formatted phone number. # # @return [String] required :phone_number, String # @!method initialize(attempt_code:, created_at:, phone_number:) # @param attempt_code [String] The fixed attempt code associated with the sandbox phone number. # # @param created_at [Time] The date and time when the phone number was added to the sandbox list. # # @param phone_number [String] An E.164 formatted phone number. end |
Instance Attribute Details
#attempt_code ⇒ String
The fixed attempt code associated with the sandbox phone number.
23 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rb', line 23 required :attempt_code, String |
#created_at ⇒ Time
The date and time when the phone number was added to the sandbox list.
29 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rb', line 29 required :created_at, Time |
#phone_number ⇒ String
An E.164 formatted phone number.
35 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rb', line 35 required :phone_number, String |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/prelude_sdk/models/verification_management/sandbox_list_phone_numbers_response.rbs', line 36 def to_hash: -> { |