Class: PreludeSDK::Models::VerificationManagementListPhoneNumbersResponse::PhoneNumber

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/verification_management_list_phone_numbers_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, phone_number:) ⇒ Object

Parameters:

  • created_at (Time)

    The date and time when the phone number was added to the list.

  • phone_number (String)

    An E.164 formatted phone number.



17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
# File 'lib/prelude_sdk/models/verification_management_list_phone_numbers_response.rb', line 17

class PhoneNumber < PreludeSDK::Internal::Type::BaseModel
  # @!attribute created_at
  #   The date and time when the phone number was added to the list.
  #
  #   @return [Time]
  required :created_at, Time

  # @!attribute phone_number
  #   An E.164 formatted phone number.
  #
  #   @return [String]
  required :phone_number, String

  # @!method initialize(created_at:, phone_number:)
  #   @param created_at [Time] The date and time when the phone number was added to the list.
  #
  #   @param phone_number [String] An E.164 formatted phone number.
end

Instance Attribute Details

#created_atTime

The date and time when the phone number was added to the list.

Returns:

  • (Time)


22
# File 'lib/prelude_sdk/models/verification_management_list_phone_numbers_response.rb', line 22

required :created_at, Time

#phone_numberString

An E.164 formatted phone number.

Returns:

  • (String)


28
# File 'lib/prelude_sdk/models/verification_management_list_phone_numbers_response.rb', line 28

required :phone_number, String