Class: PreludeSDK::Models::VerificationManagementSetPhoneNumberResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/verification_management_set_phone_number_response.rb,
sig/prelude_sdk/models/verification_management_set_phone_number_response.rbs

Overview

See Also:

  • PreludeSDK::Resources::VerificationManagement#set_phone_number

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(phone_number:) ⇒ VerificationManagementSetPhoneNumberResponse

Returns a new instance of VerificationManagementSetPhoneNumberResponse.

Parameters:

  • phone_number (String)

    The E.164 formatted phone number that was added to the list.

  • phone_number: (String)


# File 'lib/prelude_sdk/models/verification_management_set_phone_number_response.rb', line 13

Instance Attribute Details

#phone_numberString

The E.164 formatted phone number that was added to the list.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/prelude_sdk/models/verification_management_set_phone_number_response.rb', line 11

required :phone_number, String

Instance Method Details

#to_hash{ phone_number: String }

Returns:

  • ({ phone_number: String })


11
# File 'sig/prelude_sdk/models/verification_management_set_phone_number_response.rbs', line 11

def to_hash: -> { phone_number: String }