Class: PreludeSDK::Models::WatchPredictParams::Metadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/watch_predict_params.rb,
sig/prelude_sdk/models/watch_predict_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(correlation_id: nil) ⇒ Metadata

Some parameter documentations has been truncated, see PreludeSDK::Models::WatchPredictParams::Metadata for more details.

The metadata for this prediction.

Parameters:

  • correlation_id (String) (defaults to: nil) —

    A user-defined identifier to correlate this prediction with. It is returned in t

  • correlation_id: (String) (defaults to: nil)


49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 49

class Metadata < PreludeSDK::Internal::Type::BaseModel
  # @!attribute correlation_id
  #   A user-defined identifier to correlate this prediction with. It is returned in
  #   the response and any webhook events that refer to this prediction.
  #
  #   @return [String, nil]
  optional :correlation_id, String

  # @!method initialize(correlation_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {PreludeSDK::Models::WatchPredictParams::Metadata} for more details.
  #
  #   The metadata for this prediction.
  #
  #   @param correlation_id [String] A user-defined identifier to correlate this prediction with. It is returned in t
end

Instance Attribute Details

#correlation_id ⇒ String?

A user-defined identifier to correlate this prediction with. It is returned in the response and any webhook events that refer to this prediction.

Parameters:

  • (String)

Returns:

  • (String, nil)


55
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 55

optional :correlation_id, String

Instance Method Details

#to_hash ⇒ { correlation_id: String }

Returns:

  • ({ correlation_id: String })


57
# File 'sig/prelude_sdk/models/watch_predict_params.rbs', line 57

def to_hash: -> { correlation_id: String }