Class: PreludeSDK::Models::WatchPredictParams::Signals
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::WatchPredictParams::Signals
- Defined in:
- lib/prelude_sdk/models/watch_predict_params.rb
Defined Under Namespace
Modules: DevicePlatform
Instance Attribute Summary collapse
-
#app_version ⇒ String?
The version of your application.
-
#device_id ⇒ String?
A unique ID for the user’s device.
-
#device_model ⇒ String?
The model of the user’s device.
-
#device_platform ⇒ Symbol, ...
The type of the user’s device.
-
#ip ⇒ String?
The public IP v4 or v6 address of the end-user’s device.
-
#is_trusted_user ⇒ Boolean?
This signal should indicate a higher level of trust, explicitly stating that the user is genuine.
-
#ja4_fingerprint ⇒ String?
The JA4 fingerprint observed for the end-user’s connection.
-
#os_version ⇒ String?
The version of the user’s device operating system.
-
#user_agent ⇒ String?
The user agent of the user’s device.
Instance Method Summary collapse
-
#initialize(app_version: nil, device_id: nil, device_model: nil, device_platform: nil, ip: nil, is_trusted_user: nil, ja4_fingerprint: nil, os_version: nil, user_agent: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Signals for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_version: nil, device_id: nil, device_model: nil, device_platform: nil, ip: nil, is_trusted_user: nil, ja4_fingerprint: nil, os_version: nil, user_agent: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::WatchPredictParams::Signals for more details.
The signals used for anti-fraud. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).
|
|
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 166
|
Instance Attribute Details
#app_version ⇒ String?
The version of your application.
105 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 105 optional :app_version, String |
#device_id ⇒ String?
A unique ID for the user’s device. You should ensure that each user device has a unique ‘device_id` value. Ideally, for Android, this corresponds to the `ANDROID_ID` and for iOS, this corresponds to the `identifierForVendor`.
113 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 113 optional :device_id, String |
#device_model ⇒ String?
The model of the user’s device.
119 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 119 optional :device_model, String |
#device_platform ⇒ Symbol, ...
The type of the user’s device.
125 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 125 optional :device_platform, enum: -> { PreludeSDK::WatchPredictParams::Signals::DevicePlatform } |
#ip ⇒ String?
The public IP v4 or v6 address of the end-user’s device. You should collect this from your backend. If your backend is behind a proxy, use the ‘X-Forwarded-For`, `Forwarded`, `True-Client-IP`, `CF-Connecting-IP` or an equivalent header to get the actual public IP of the end-user’s device.
134 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 134 optional :ip, String |
#is_trusted_user ⇒ Boolean?
This signal should indicate a higher level of trust, explicitly stating that the user is genuine. Contact us to discuss your use case. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).
142 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 142 optional :is_trusted_user, PreludeSDK::Internal::Type::Boolean |
#ja4_fingerprint ⇒ String?
The JA4 fingerprint observed for the end-user’s connection. Prelude will infer it automatically when you use our Frontend SDKs (which use Prelude’s edge network), but you can also forward the value if you terminate TLS yourself.
150 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 150 optional :ja4_fingerprint, String |
#os_version ⇒ String?
The version of the user’s device operating system.
156 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 156 optional :os_version, String |
#user_agent ⇒ String?
The user agent of the user’s device. If the individual fields (os_version, device_platform, device_model) are provided, we will prioritize those values instead of parsing them from the user agent string.
164 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 164 optional :user_agent, String |