Class: PreludeSDK::Models::WatchPredictResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::WatchPredictResponse
- Defined in:
- lib/prelude_sdk/models/watch_predict_response.rb,
sig/prelude_sdk/models/watch_predict_response.rbs
Overview
Defined Under Namespace
Modules: Prediction, RiskFactor
Instance Attribute Summary collapse
-
#id ⇒ String
The prediction identifier.
-
#prediction ⇒ Symbol, PreludeSDK::Models::WatchPredictResponse::Prediction
The prediction outcome.
-
#request_id ⇒ String
A string that identifies this specific request.
-
#risk_factors ⇒ Array<Symbol, PreludeSDK::Models::WatchPredictResponse::RiskFactor>?
The risk factors that contributed to the suspicious prediction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, prediction:, request_id:, risk_factors: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WatchPredictResponse for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, prediction:, request_id:, risk_factors: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::WatchPredictResponse for more details.
|
|
# File 'lib/prelude_sdk/models/watch_predict_response.rb', line 56
|
Instance Attribute Details
#id ⇒ String
The prediction identifier.
11 |
# File 'lib/prelude_sdk/models/watch_predict_response.rb', line 11 required :id, String |
#prediction ⇒ Symbol, PreludeSDK::Models::WatchPredictResponse::Prediction
The prediction outcome.
17 |
# File 'lib/prelude_sdk/models/watch_predict_response.rb', line 17 required :prediction, enum: -> { PreludeSDK::Models::WatchPredictResponse::Prediction } |
#request_id ⇒ String
A string that identifies this specific request. Report it back to us to help us diagnose your issues.
24 |
# File 'lib/prelude_sdk/models/watch_predict_response.rb', line 24 required :request_id, String |
#risk_factors ⇒ Array<Symbol, PreludeSDK::Models::WatchPredictResponse::RiskFactor>?
The risk factors that contributed to the suspicious prediction. Only present when prediction is "suspicious" and the anti-fraud system detected specific risk signals.
behavioral_pattern- The phone number past behavior during verification flows exhibits suspicious patterns.device_attribute- The device exhibits characteristics associated with suspicious activity patterns.fraud_database- The phone number has been flagged as suspicious in one or more of our fraud databases.location_discrepancy- The phone number prefix and IP address discrepancy indicates potential fraud.network_fingerprint- The network connection exhibits characteristics associated with suspicious activity patterns.poor_conversion_history- The phone number has a history of poorly converting to a verified phone number.prefix_concentration- The phone number is part of a range known to be associated with suspicious activity patterns.suspected_request_tampering- The SDK signature is invalid and the request is considered to be tampered with.suspicious_ip_address- The IP address is deemed to be associated with suspicious activity patterns.temporary_phone_number- The phone number is known to be a temporary or disposable number.
53 54 |
# File 'lib/prelude_sdk/models/watch_predict_response.rb', line 53 optional :risk_factors, -> { PreludeSDK::Internal::Type::ArrayOf[enum: PreludeSDK::Models::WatchPredictResponse::RiskFactor] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/watch_predict_response.rb', line 77
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/prelude_sdk/models/watch_predict_response.rbs', line 31
def to_hash: -> {
|