Class: PreludeSDK::Models::WatchSendFeedbacksParams::Feedback::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::WatchSendFeedbacksParams::Feedback::Metadata
- Defined in:
- lib/prelude_sdk/models/watch_send_feedbacks_params.rb
Overview
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
A user-defined identifier to correlate this feedback with.
Instance Method Summary collapse
-
#initialize(correlation_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(correlation_id: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::WatchSendFeedbacksParams::Feedback::Metadata for more details.
The metadata for this feedback.
|
|
# File 'lib/prelude_sdk/models/watch_send_feedbacks_params.rb', line 109
|
Instance Attribute Details
#correlation_id ⇒ String?
A user-defined identifier to correlate this feedback with. It is returned in the response and any webhook events that refer to this feedback.
107 |
# File 'lib/prelude_sdk/models/watch_send_feedbacks_params.rb', line 107 optional :correlation_id, String |