Class: PreludeSDK::Resources::Intel
- Inherits:
-
Object
- Object
- PreludeSDK::Resources::Intel
- Defined in:
- lib/prelude_sdk/resources/intel.rb,
lib/prelude_sdk/resources/intel/kyc.rb,
sig/prelude_sdk/resources/intel.rbs,
sig/prelude_sdk/resources/intel/kyc.rbs
Defined Under Namespace
Classes: KYC
Instance Attribute Summary collapse
-
#kyc ⇒ PreludeSDK::Resources::Intel::KYC
readonly
Retrieve detailed information about a phone number including carrier data, line type, and portability status.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Intel
constructor
private
A new instance of Intel.
Constructor Details
#initialize(client:) ⇒ Intel
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Intel.
14 15 16 17 |
# File 'lib/prelude_sdk/resources/intel.rb', line 14 def initialize(client:) @client = client @kyc = PreludeSDK::Resources::Intel::KYC.new(client: client) end |
Instance Attribute Details
#kyc ⇒ PreludeSDK::Resources::Intel::KYC (readonly)
Retrieve detailed information about a phone number including carrier data, line type, and portability status.
9 10 11 |
# File 'lib/prelude_sdk/resources/intel.rb', line 9 def kyc @kyc end |