Class: PreludeSDK::Models::Intel::KYCMatchParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::Intel::KYCMatchParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/intel/kyc_match_params.rb,
sig/prelude_sdk/models/intel/kyc_match_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::PreludeSDK
Instance Attribute Summary collapse
-
#address ⇒ String?
The street address.
-
#birthdate ⇒ Date?
The date of birth in ISO 8601 (
YYYY-MM-DD) format. -
#country ⇒ String?
The ISO 3166-1 alpha-2 country code.
-
#email ⇒ String?
The email address.
-
#family_name ⇒ String?
The end-user's family (last) name.
-
#given_name ⇒ String?
The end-user's given (first) name.
-
#locality ⇒ String?
The locality (city).
-
#phone ⇒ String
An E.164 formatted phone number whose subscriber identity to match against.
-
#postal_code ⇒ String?
The postal code.
-
#region ⇒ String?
The region, state, or province.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(phone:, address: nil, birthdate: nil, country: nil, email: nil, family_name: nil, given_name: nil, locality: nil, postal_code: nil, region: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(phone:, address: nil, birthdate: nil, country: nil, email: nil, family_name: nil, given_name: nil, locality: nil, postal_code: nil, region: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 71
|
Instance Attribute Details
#address ⇒ String?
The street address.
21 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 21 optional :address, String |
#birthdate ⇒ Date?
The date of birth in ISO 8601 (YYYY-MM-DD) format. Compared exactly.
27 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 27 optional :birthdate, Date |
#country ⇒ String?
The ISO 3166-1 alpha-2 country code. Compared exactly.
33 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 33 optional :country, String |
#email ⇒ String?
The email address.
39 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 39 optional :email, String |
#family_name ⇒ String?
The end-user's family (last) name.
45 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 45 optional :family_name, String |
#given_name ⇒ String?
The end-user's given (first) name.
51 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 51 optional :given_name, String |
#locality ⇒ String?
The locality (city).
57 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 57 optional :locality, String |
#phone ⇒ String
An E.164 formatted phone number whose subscriber identity to match against.
15 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 15 required :phone, String |
#postal_code ⇒ String?
The postal code. Compared exactly.
63 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 63 optional :postal_code, String |
#region ⇒ String?
The region, state, or province.
69 |
# File 'lib/prelude_sdk/models/intel/kyc_match_params.rb', line 69 optional :region, String |
Instance Method Details
#to_hash ⇒ {
75 |
# File 'sig/prelude_sdk/models/intel/kyc_match_params.rbs', line 75
def to_hash: -> {
|