Module: PreludeSDK::Models::LookupLookupResponse::LineType

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/lookup_lookup_response.rb

Overview

The type of phone line.

  • ‘calling_cards` - Numbers that are associated with providers of pre-paid domestic and international calling cards.

  • ‘fixed_line` - Landline phone numbers.

  • ‘isp` - Numbers reserved for Internet Service Providers.

  • ‘local_rate` - Numbers that can be assigned non-geographically.

  • ‘mobile` - Mobile phone numbers.

  • ‘other` - Other types of services.

  • ‘pager` - Number ranges specifically allocated to paging devices.

  • ‘payphone` - Allocated numbers for payphone kiosks in some countries.

  • ‘premium_rate` - Landline numbers where the calling party pays more than standard.

  • ‘satellite` - Satellite phone numbers.

  • ‘service` - Automated applications.

  • ‘shared_cost` - Specific landline ranges where the cost of making the call is shared between the calling and called party.

  • ‘short_codes_commercial` - Short codes are memorable, easy-to-use numbers, like the UK’s NHS 111, often sold to businesses. Not available in all countries.

  • ‘toll_free` - Number where the called party pays for the cost of the call not the calling party.

  • ‘universal_access` - Number ranges reserved for Universal Access initiatives.

  • ‘unknown` - Unknown phone number type.

  • ‘vpn` - Numbers are used exclusively within a private telecommunications network, connecting the operator’s terminals internally and not accessible via the public telephone network.

  • ‘voice_mail` - A specific category of Interactive Voice Response (IVR) services.

  • ‘voip` - Specific ranges for providers of VoIP services to allow incoming calls from the regular telephony network.

See Also:

Constant Summary collapse

CALLING_CARDS =
:calling_cards
FIXED_LINE =
:fixed_line
ISP =
:isp
LOCAL_RATE =
:local_rate
MOBILE =
:mobile
OTHER =
:other
PAGER =
:pager
PAYPHONE =
:payphone
PREMIUM_RATE =
:premium_rate
SATELLITE =
:satellite
SERVICE =
:service
SHARED_COST =
:shared_cost
SHORT_CODES_COMMERCIAL =
:short_codes_commercial
TOLL_FREE =
:toll_free
UNIVERSAL_ACCESS =
:universal_access
UNKNOWN =
:unknown
VPN =
:vpn
VOICE_MAIL =
:voice_mail
VOIP =
:voip

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info