Class: PreludeSDK::Models::NotifyReplyParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifyReplyParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/notify_reply_params.rb,
sig/prelude_sdk/models/notify_reply_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::PreludeSDK
Instance Attribute Summary collapse
-
#callback_url ⇒ String?
The URL where webhooks will be sent for delivery events of this reply.
-
#correlation_id ⇒ String?
A user-defined identifier to correlate this reply with your internal systems.
-
#reply_to ⇒ String
The inbound message ID (prefixed with
im_) to reply to. -
#text ⇒ String
The reply message body sent as a free-form WhatsApp text.
-
#to ⇒ String
The recipient's phone number in E.164 format.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(reply_to:, text:, to:, callback_url: nil, correlation_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see NotifyReplyParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(reply_to:, text:, to:, callback_url: nil, correlation_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::NotifyReplyParams for more details.
|
|
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 43
|
Instance Attribute Details
#callback_url ⇒ String?
The URL where webhooks will be sent for delivery events of this reply.
34 |
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 34 optional :callback_url, String |
#correlation_id ⇒ String?
A user-defined identifier to correlate this reply with your internal systems. It is returned in the response and any webhook events that refer to this message.
41 |
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 41 optional :correlation_id, String |
#reply_to ⇒ String
The inbound message ID (prefixed with im_) to reply to. This ID is provided in
the inbound.message.received webhook event.
15 |
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 15 required :reply_to, String |
#text ⇒ String
The reply message body sent as a free-form WhatsApp text.
21 |
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 21 required :text, String |
#to ⇒ String
The recipient's phone number in E.164 format. Must match the phone number that sent the original inbound message.
28 |
# File 'lib/prelude_sdk/models/notify_reply_params.rb', line 28 required :to, String |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/prelude_sdk/models/notify_reply_params.rbs', line 40
def to_hash: -> {
|