Class: PreludeSDK::Models::NotifySendBatchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/notify_send_batch_params.rb

Overview

Defined Under Namespace

Modules: PreferredChannel Classes: Document

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url:, filename: nil) ⇒ Object

Some parameter documentations has been truncated, see Document for more details.

A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.

  • ‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.

  • ‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.

  • ‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.

Parameters:

  • url (String)

    HTTPS URL of the media file. The file extension must match the template’s regist

  • filename (String) (defaults to: nil)

    Filename displayed to the recipient. Required for templates with a ‘DOCUMENT` he



# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 131

Instance Attribute Details

#callback_urlString?

The URL where webhooks will be sent for delivery events.

Returns:

  • (String, nil)


26
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 26

optional :callback_url, String

#correlation_idString?

A user-defined identifier to correlate this request with your internal systems.

Returns:

  • (String, nil)


32
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 32

optional :correlation_id, String

#documentPreludeSDK::Models::NotifySendBatchParams::Document?

A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.

  • ‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.

  • ‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.

  • ‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.



47
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 47

optional :document, -> { PreludeSDK::NotifySendBatchParams::Document }

#expires_atTime?

The message expiration date in RFC3339 format. Messages will not be sent after this time.

Returns:

  • (Time, nil)


54
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 54

optional :expires_at, Time

#fromString?

The Sender ID. Must be approved for your account.

Returns:

  • (String, nil)


60
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 60

optional :from, String

#localeString?

A BCP-47 formatted locale string.

Returns:

  • (String, nil)


66
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 66

optional :locale, String

#preferred_channelSymbol, ...

Preferred channel for delivery. If unavailable, automatic fallback applies.



72
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 72

optional :preferred_channel, enum: -> { PreludeSDK::NotifySendBatchParams::PreferredChannel }

#schedule_atTime?

Schedule delivery in RFC3339 format. Marketing sends may be adjusted to comply with local time windows.

Returns:

  • (Time, nil)


79
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 79

optional :schedule_at, Time

#template_idString

The template identifier configured by your Customer Success team.

Returns:

  • (String)


14
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 14

required :template_id, String

#toArray<String>

The list of recipients’ phone numbers in E.164 format.

Returns:

  • (Array<String>)


20
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 20

required :to, PreludeSDK::Internal::Type::ArrayOf[String]

#variablesHash{Symbol=>String}?

The variables to be replaced in the template.

Returns:

  • (Hash{Symbol=>String}, nil)


85
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 85

optional :variables, PreludeSDK::Internal::Type::HashOf[String]