Class: PreludeSDK::Models::NotifySendBatchParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifySendBatchParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/notify_send_batch_params.rb
Overview
Defined Under Namespace
Modules: PreferredChannel Classes: Document
Instance Attribute Summary collapse
-
#callback_url ⇒ String?
The URL where webhooks will be sent for delivery events.
-
#correlation_id ⇒ String?
A user-defined identifier to correlate this request with your internal systems.
-
#document ⇒ PreludeSDK::Models::NotifySendBatchParams::Document?
A media attachment to include in the message header.
-
#expires_at ⇒ Time?
The message expiration date in RFC3339 format.
-
#from ⇒ String?
The Sender ID.
-
#locale ⇒ String?
A BCP-47 formatted locale string.
-
#preferred_channel ⇒ Symbol, ...
Preferred channel for delivery.
-
#schedule_at ⇒ Time?
Schedule delivery in RFC3339 format.
-
#template_id ⇒ String
The template identifier configured by your Customer Success team.
-
#to ⇒ Array<String>
The list of recipients’ phone numbers in E.164 format.
-
#variables ⇒ Hash{Symbol=>String}?
The variables to be replaced in the template.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(url:, filename: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Document for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, filename: nil) ⇒ Object
Some parameter documentations has been truncated, see Document for more details.
A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.
-
‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.
-
‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.
-
‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.
|
|
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 131
|
Instance Attribute Details
#callback_url ⇒ String?
The URL where webhooks will be sent for delivery events.
26 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 26 optional :callback_url, String |
#correlation_id ⇒ String?
A user-defined identifier to correlate this request with your internal systems.
32 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 32 optional :correlation_id, String |
#document ⇒ PreludeSDK::Models::NotifySendBatchParams::Document?
A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.
-
‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.
-
‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.
-
‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.
47 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 47 optional :document, -> { PreludeSDK::NotifySendBatchParams::Document } |
#expires_at ⇒ Time?
The message expiration date in RFC3339 format. Messages will not be sent after this time.
54 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 54 optional :expires_at, Time |
#from ⇒ String?
The Sender ID. Must be approved for your account.
60 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 60 optional :from, String |
#locale ⇒ String?
A BCP-47 formatted locale string.
66 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 66 optional :locale, String |
#preferred_channel ⇒ Symbol, ...
Preferred channel for delivery. If unavailable, automatic fallback applies.
72 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 72 optional :preferred_channel, enum: -> { PreludeSDK::NotifySendBatchParams::PreferredChannel } |
#schedule_at ⇒ Time?
Schedule delivery in RFC3339 format. Marketing sends may be adjusted to comply with local time windows.
79 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 79 optional :schedule_at, Time |
#template_id ⇒ String
The template identifier configured by your Customer Success team.
14 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 14 required :template_id, String |
#to ⇒ Array<String>
The list of recipients’ phone numbers in E.164 format.
20 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 20 required :to, PreludeSDK::Internal::Type::ArrayOf[String] |
#variables ⇒ Hash{Symbol=>String}?
The variables to be replaced in the template.
85 |
# File 'lib/prelude_sdk/models/notify_send_batch_params.rb', line 85 optional :variables, PreludeSDK::Internal::Type::HashOf[String] |