Class: PreludeSDK::Models::NotifySendBatchResponse::Result
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifySendBatchResponse::Result
- Defined in:
- lib/prelude_sdk/models/notify_send_batch_response.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#error ⇒ PreludeSDK::Models::NotifySendBatchResponse::Result::Error?
Present only if success is false.
-
#message ⇒ PreludeSDK::Models::NotifySendBatchResponse::Result::Message?
Present only if success is true.
-
#phone_number ⇒ String
The recipient’s phone number in E.164 format.
-
#success ⇒ Boolean
Whether the message was accepted for delivery.
Instance Method Summary collapse
-
#initialize(code: nil, message: nil) ⇒ Object
constructor
Present only if success is false.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code: nil, message: nil) ⇒ Object
Present only if success is false.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 73 class Result < PreludeSDK::Internal::Type::BaseModel # @!attribute phone_number # The recipient's phone number in E.164 format. # # @return [String] required :phone_number, String # @!attribute success # Whether the message was accepted for delivery. # # @return [Boolean] required :success, PreludeSDK::Internal::Type::Boolean # @!attribute error # Present only if success is false. # # @return [PreludeSDK::Models::NotifySendBatchResponse::Result::Error, nil] optional :error, -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Error } # @!attribute message # Present only if success is true. # # @return [PreludeSDK::Models::NotifySendBatchResponse::Result::Message, nil] optional :message, -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Message } # @!method initialize(phone_number:, success:, error: nil, message: nil) # @param phone_number [String] The recipient's phone number in E.164 format. # # @param success [Boolean] Whether the message was accepted for delivery. # # @param error [PreludeSDK::Models::NotifySendBatchResponse::Result::Error] Present only if success is false. # # @param message [PreludeSDK::Models::NotifySendBatchResponse::Result::Message] Present only if success is true. # @see PreludeSDK::Models::NotifySendBatchResponse::Result#error class Error < PreludeSDK::Internal::Type::BaseModel # @!attribute code # The error code. # # @return [String, nil] optional :code, String # @!attribute message # A human-readable error message. # # @return [String, nil] optional :message, String # @!method initialize(code: nil, message: nil) # Present only if success is false. # # @param code [String] The error code. # # @param message [String] A human-readable error message. end # @see PreludeSDK::Models::NotifySendBatchResponse::Result#message class Message < PreludeSDK::Internal::Type::BaseModel # @!attribute id # The message identifier. # # @return [String, nil] optional :id, String # @!attribute correlation_id # The correlation identifier for the message. # # @return [String, nil] optional :correlation_id, String # @!attribute created_at # The message creation date in RFC3339 format. # # @return [Time, nil] optional :created_at, Time # @!attribute encoding # The SMS encoding type based on message content. GSM-7 supports standard # characters (up to 160 chars per segment), while UCS-2 supports Unicode including # emoji (up to 70 chars per segment). Only present for SMS messages. # # @return [Symbol, PreludeSDK::Models::NotifySendBatchResponse::Result::Message::Encoding, nil] optional :encoding, enum: -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Message::Encoding } # @!attribute estimated_segment_count # The estimated number of SMS segments for this message. This value is not # contractual; the actual segment count will be determined after the SMS is sent # by the provider. Only present for SMS messages. # # @return [Integer, nil] optional :estimated_segment_count, Integer # @!attribute expires_at # The message expiration date in RFC3339 format. # # @return [Time, nil] optional :expires_at, Time # @!attribute from # The Sender ID used for this message. # # @return [String, nil] optional :from, String # @!attribute locale # The locale used for the message, if any. # # @return [String, nil] optional :locale, String # @!attribute schedule_at # When the message will actually be sent in RFC3339 format with timezone offset. # # @return [Time, nil] optional :schedule_at, Time # @!attribute to # The recipient's phone number in E.164 format. # # @return [String, nil] optional :to, String # @!method initialize(id: nil, correlation_id: nil, created_at: nil, encoding: nil, estimated_segment_count: nil, expires_at: nil, from: nil, locale: nil, schedule_at: nil, to: nil) # Some parameter documentations has been truncated, see # {PreludeSDK::Models::NotifySendBatchResponse::Result::Message} for more details. # # Present only if success is true. # # @param id [String] The message identifier. # # @param correlation_id [String] The correlation identifier for the message. # # @param created_at [Time] The message creation date in RFC3339 format. # # @param encoding [Symbol, PreludeSDK::Models::NotifySendBatchResponse::Result::Message::Encoding] The SMS encoding type based on message content. GSM-7 supports standard characte # # @param estimated_segment_count [Integer] The estimated number of SMS segments for this message. This value is not contrac # # @param expires_at [Time] The message expiration date in RFC3339 format. # # @param from [String] The Sender ID used for this message. # # @param locale [String] The locale used for the message, if any. # # @param schedule_at [Time] When the message will actually be sent in RFC3339 format with timezone offset. # # @param to [String] The recipient's phone number in E.164 format. # The SMS encoding type based on message content. GSM-7 supports standard # characters (up to 160 chars per segment), while UCS-2 supports Unicode including # emoji (up to 70 chars per segment). Only present for SMS messages. # # @see PreludeSDK::Models::NotifySendBatchResponse::Result::Message#encoding module Encoding extend PreludeSDK::Internal::Type::Enum GSM_7 = :"GSM-7" UCS_2 = :"UCS-2" # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#error ⇒ PreludeSDK::Models::NotifySendBatchResponse::Result::Error?
Present only if success is false.
90 |
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 90 optional :error, -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Error } |
#message ⇒ PreludeSDK::Models::NotifySendBatchResponse::Result::Message?
Present only if success is true.
96 |
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 96 optional :message, -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Message } |
#phone_number ⇒ String
The recipient’s phone number in E.164 format.
78 |
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 78 required :phone_number, String |
#success ⇒ Boolean
Whether the message was accepted for delivery.
84 |
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 84 required :success, PreludeSDK::Internal::Type::Boolean |