Class: PreludeSDK::Models::NotifySendBatchResponse::Result::Message

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/notify_send_batch_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Encoding

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, correlation_id: nil, created_at: nil, encoding: nil, estimated_segment_count: nil, expires_at: nil, from: nil, locale: nil, schedule_at: nil, to: nil) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::NotifySendBatchResponse::Result::Message for more details.

Present only if success is true.

Parameters:

  • id (String) (defaults to: nil)

    The message identifier.

  • correlation_id (String) (defaults to: nil)

    The correlation identifier for the message.

  • created_at (Time) (defaults to: nil)

    The message creation date in RFC3339 format.

  • encoding (Symbol, PreludeSDK::Models::NotifySendBatchResponse::Result::Message::Encoding) (defaults to: nil)

    The SMS encoding type based on message content. GSM-7 supports standard characte

  • estimated_segment_count (Integer) (defaults to: nil)

    The estimated number of SMS segments for this message. This value is not contrac

  • expires_at (Time) (defaults to: nil)

    The message expiration date in RFC3339 format.

  • from (String) (defaults to: nil)

    The Sender ID used for this message.

  • locale (String) (defaults to: nil)

    The locale used for the message, if any.

  • schedule_at (Time) (defaults to: nil)

    When the message will actually be sent in RFC3339 format with timezone offset.

  • to (String) (defaults to: nil)

    The recipient’s phone number in E.164 format.



# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 195

Instance Attribute Details

#correlation_idString?

The correlation identifier for the message.

Returns:

  • (String, nil)


141
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 141

optional :correlation_id, String

#created_atTime?

The message creation date in RFC3339 format.

Returns:

  • (Time, nil)


147
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 147

optional :created_at, Time

#encodingSymbol, ...

The SMS encoding type based on message content. GSM-7 supports standard characters (up to 160 chars per segment), while UCS-2 supports Unicode including emoji (up to 70 chars per segment). Only present for SMS messages.



155
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 155

optional :encoding, enum: -> { PreludeSDK::Models::NotifySendBatchResponse::Result::Message::Encoding }

#estimated_segment_countInteger?

The estimated number of SMS segments for this message. This value is not contractual; the actual segment count will be determined after the SMS is sent by the provider. Only present for SMS messages.

Returns:

  • (Integer, nil)


163
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 163

optional :estimated_segment_count, Integer

#expires_atTime?

The message expiration date in RFC3339 format.

Returns:

  • (Time, nil)


169
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 169

optional :expires_at, Time

#fromString?

The Sender ID used for this message.

Returns:

  • (String, nil)


175
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 175

optional :from, String

#idString?

The message identifier.

Returns:

  • (String, nil)


135
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 135

optional :id, String

#localeString?

The locale used for the message, if any.

Returns:

  • (String, nil)


181
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 181

optional :locale, String

#schedule_atTime?

When the message will actually be sent in RFC3339 format with timezone offset.

Returns:

  • (Time, nil)


187
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 187

optional :schedule_at, Time

#toString?

The recipient’s phone number in E.164 format.

Returns:

  • (String, nil)


193
# File 'lib/prelude_sdk/models/notify_send_batch_response.rb', line 193

optional :to, String