Class: PreludeSDK::Models::NotifySendParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/notify_send_params.rb

Overview

Defined Under Namespace

Modules: PreferredChannel Classes: Document

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url:, filename: nil) ⇒ Object

Some parameter documentations has been truncated, see Document for more details.

A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.

  • ‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.

  • ‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.

  • ‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.

Parameters:

  • url (String)

    HTTPS URL of the media file. The file extension must match the template’s regist

  • filename (String) (defaults to: nil)

    Filename displayed to the recipient. Required for templates with a ‘DOCUMENT` he



# File 'lib/prelude_sdk/models/notify_send_params.rb', line 138

Instance Attribute Details

#callback_urlString?

The URL where webhooks will be sent for message delivery events.

Returns:

  • (String, nil)


26
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 26

optional :callback_url, String

#correlation_idString?

A user-defined identifier to correlate this message with your internal systems. It is returned in the response and any webhook events that refer to this message.

Returns:

  • (String, nil)


34
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 34

optional :correlation_id, String

#documentPreludeSDK::Models::NotifySendParams::Document?

A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.

  • ‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.

  • ‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.

  • ‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.



49
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 49

optional :document, -> { PreludeSDK::NotifySendParams::Document }

#expires_atTime?

The message expiration date in RFC3339 format. The message will not be sent if this time is reached.

Returns:

  • (Time, nil)


56
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 56

optional :expires_at, Time

#fromString?

The Sender ID. Must be approved for your account.

Returns:

  • (String, nil)


62
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 62

optional :from, String

#localeString?

A BCP-47 formatted locale string with the language the text message will be sent to. If there’s no locale set, the language will be determined by the country code of the phone number. If the language specified doesn’t exist, the default set on the template will be used.

Returns:

  • (String, nil)


71
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 71

optional :locale, String

#preferred_channelSymbol, ...

The preferred channel to be used in priority for message delivery. If the channel is unavailable, the system will fallback to other available channels.



78
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 78

optional :preferred_channel, enum: -> { PreludeSDK::NotifySendParams::PreferredChannel }

#schedule_atTime?

Schedule the message for future delivery in RFC3339 format. Marketing messages can be scheduled up to 90 days in advance and will be automatically adjusted for compliance with local time window restrictions.

Returns:

  • (Time, nil)


86
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 86

optional :schedule_at, Time

#template_idString

The template identifier configured by your Customer Success team.

Returns:

  • (String)


14
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 14

required :template_id, String

#toString

The recipient’s phone number in E.164 format.

Returns:

  • (String)


20
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 20

required :to, String

#variablesHash{Symbol=>String}?

The variables to be replaced in the template.

Returns:

  • (Hash{Symbol=>String}, nil)


92
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 92

optional :variables, PreludeSDK::Internal::Type::HashOf[String]