Class: PreludeSDK::Models::NotifySendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::NotifySendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/notify_send_params.rb
Overview
Defined Under Namespace
Modules: PreferredChannel Classes: Context, Document
Instance Attribute Summary collapse
-
#callback_url ⇒ String?
The URL where webhooks will be sent for message delivery events.
-
#context ⇒ PreludeSDK::Models::NotifySendParams::Context?
Context for replying to an inbound message.
-
#correlation_id ⇒ String?
A user-defined identifier to correlate this message with your internal systems.
-
#document ⇒ PreludeSDK::Models::NotifySendParams::Document?
A media attachment to include in the message header.
-
#expires_at ⇒ Time?
The message expiration date in RFC3339 format.
-
#from ⇒ String?
The Sender ID.
-
#locale ⇒ String?
A BCP-47 formatted locale string with the language the text message will be sent to.
-
#preferred_channel ⇒ Symbol, ...
The preferred channel to be used in priority for message delivery.
-
#schedule_at ⇒ Time?
Schedule the message for future delivery in RFC3339 format.
-
#template_id ⇒ String
The template identifier configured by your Customer Success team.
-
#text ⇒ String?
The reply message body.
-
#to ⇒ String
The recipient’s phone number in E.164 format.
-
#variables ⇒ Hash{Symbol=>String}?
The variables to be replaced in the template.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(url:, filename: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Document for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, filename: nil) ⇒ Object
Some parameter documentations has been truncated, see Document for more details.
A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.
-
‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.
-
‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.
-
‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.
|
|
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 149
|
Instance Attribute Details
#callback_url ⇒ String?
The URL where webhooks will be sent for message delivery events.
26 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 26 optional :callback_url, String |
#context ⇒ PreludeSDK::Models::NotifySendParams::Context?
Context for replying to an inbound message. When provided, the message is sent as a WhatsApp reply within the 24-hour conversation window.
33 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 33 optional :context, -> { PreludeSDK::NotifySendParams::Context } |
#correlation_id ⇒ String?
A user-defined identifier to correlate this message with your internal systems. It is returned in the response and any webhook events that refer to this message.
41 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 41 optional :correlation_id, String |
#document ⇒ PreludeSDK::Models::NotifySendParams::Document?
A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.
-
‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.
-
‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.
-
‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.
56 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 56 optional :document, -> { PreludeSDK::NotifySendParams::Document } |
#expires_at ⇒ Time?
The message expiration date in RFC3339 format. The message will not be sent if this time is reached.
63 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 63 optional :expires_at, Time |
#from ⇒ String?
The Sender ID. Must be approved for your account.
69 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 69 optional :from, String |
#locale ⇒ String?
A BCP-47 formatted locale string with the language the text message will be sent to. If there’s no locale set, the language will be determined by the country code of the phone number. If the language specified doesn’t exist, the default set on the template will be used.
78 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 78 optional :locale, String |
#preferred_channel ⇒ Symbol, ...
The preferred channel to be used in priority for message delivery. If the channel is unavailable, the system will fallback to other available channels.
85 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 85 optional :preferred_channel, enum: -> { PreludeSDK::NotifySendParams::PreferredChannel } |
#schedule_at ⇒ Time?
Schedule the message for future delivery in RFC3339 format. Marketing messages can be scheduled up to 90 days in advance and will be automatically adjusted for compliance with local time window restrictions.
93 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 93 optional :schedule_at, Time |
#template_id ⇒ String
The template identifier configured by your Customer Success team.
14 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 14 required :template_id, String |
#text ⇒ String?
The reply message body. Required when ‘context.reply_to` is provided. Used for 2-way WhatsApp messaging to send free-form text replies within a conversation window.
101 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 101 optional :text, String |
#to ⇒ String
The recipient’s phone number in E.164 format.
20 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 20 required :to, String |
#variables ⇒ Hash{Symbol=>String}?
The variables to be replaced in the template.
107 |
# File 'lib/prelude_sdk/models/notify_send_params.rb', line 107 optional :variables, PreludeSDK::Internal::Type::HashOf[String] |