Class: PreludeSDK::Models::TransactionalSendParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/transactional_send_params.rb

Overview

Defined Under Namespace

Modules: PreferredChannel Classes: Document

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url:, filename: nil) ⇒ Object

Some parameter documentations has been truncated, see Document for more details.

A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.

  • ‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.

  • ‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.

  • ‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.

Parameters:

  • url (String)

    HTTPS URL of the media file. The file extension must match the template’s regist

  • filename (String) (defaults to: nil)

    Filename displayed to the recipient. Required for templates with a ‘DOCUMENT` he



# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 134

Instance Attribute Details

#callback_urlString?

The callback URL.

Returns:

  • (String, nil)


26
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 26

optional :callback_url, String

#correlation_idString?

A user-defined identifier to correlate this transactional message with. It is returned in the response and any webhook events that refer to this transactionalmessage.

Returns:

  • (String, nil)


34
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 34

optional :correlation_id, String

#documentPreludeSDK::Models::TransactionalSendParams::Document?

A media attachment to include in the message header. Supported on WhatsApp templates registered with a ‘DOCUMENT`, `IMAGE`, or `VIDEO` header. The media type is determined by the template’s registered header format; send the matching file type for each.

  • ‘DOCUMENT` headers accept PDF and other document formats; `filename` is required and displayed to the recipient.

  • ‘IMAGE` headers accept `.png`, `.jpg`, `.jpeg`, and `.webp` URLs; `filename` is ignored.

  • ‘VIDEO` headers accept `.mp4` and `.3gp` URLs; `filename` is ignored.



49
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 49

optional :document, -> { PreludeSDK::TransactionalSendParams::Document }

#expires_atString?

The message expiration date.

Returns:

  • (String, nil)


55
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 55

optional :expires_at, String

#fromString?

The Sender ID.

Returns:

  • (String, nil)


61
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 61

optional :from, String

#localeString?

A BCP-47 formatted locale string with the language the text message will be sent to. If there’s no locale set, the language will be determined by the country code of the phone number. If the language specified doesn’t exist, the default set on the template will be used.

Returns:

  • (String, nil)


70
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 70

optional :locale, String

#preferred_channelSymbol, ...

The preferred delivery channel for the message. When specified, the system will prioritize sending via the requested channel if the template is configured for it.

If not specified and the template is configured for WhatsApp, the message will be sent via WhatsApp first, with automatic fallback to SMS if WhatsApp delivery is unavailable.

Supported channels: ‘sms`, `rcs`, `whatsapp`.



84
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 84

optional :preferred_channel, enum: -> { PreludeSDK::TransactionalSendParams::PreferredChannel }

#template_idString

The template identifier.

Returns:

  • (String)


14
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 14

required :template_id, String

#toString

The recipient’s phone number.

Returns:

  • (String)


20
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 20

required :to, String

#variablesHash{Symbol=>String}?

The variables to be replaced in the template.

Returns:

  • (Hash{Symbol=>String}, nil)


90
# File 'lib/prelude_sdk/models/transactional_send_params.rb', line 90

optional :variables, PreludeSDK::Internal::Type::HashOf[String]