Class: PreludeSDK::Models::Verification::Phone::HistoryListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::Verification::Phone::HistoryListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/verification/phone/history_list_params.rb,
sig/prelude_sdk/models/verification/phone/history_list_params.rbs
Overview
Defined Under Namespace
Modules: Channel, DevicePlatform, Status
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::PreludeSDK
Instance Attribute Summary collapse
-
#channels ⇒ Array<Symbol, PreludeSDK::Models::Verification::Phone::HistoryListParams::Channel>?
Only verifications that could use one of these channels.
-
#cursor ⇒ String?
Pagination cursor from the previous response.
-
#device_platform ⇒ Symbol, ...
Only verifications created from this device platform.
-
#from ⇒ Time?
Only verifications created at or after this RFC 3339 timestamp.
-
#limit ⇒ Integer?
Maximum number of verifications to return per page.
-
#max_attempts ⇒ Integer?
Only verifications that sent at most this many messages.
-
#min_attempts ⇒ Integer?
Only verifications that sent at least this many messages.
-
#phone_number ⇒ String?
Only verifications targeting this E.164 phone number.
-
#region ⇒ String?
Only verifications of phone numbers from this region, as an ISO 3166-1 alpha-2 code.
-
#status ⇒ Symbol, ...
Only verifications in this status.
-
#template_id ⇒ String?
Only verifications sent with this template, as returned in
template_idby Get a phone verification. -
#to ⇒ Time?
Only verifications created at or before this RFC 3339 timestamp.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
80 |
# File 'sig/prelude_sdk/models/verification/phone/history_list_params.rbs', line 80
def initialize: (
|
Instance Attribute Details
#channels ⇒ Array<Symbol, PreludeSDK::Models::Verification::Phone::HistoryListParams::Channel>?
Only verifications that could use one of these channels. Repeat the parameter for several values.
17 18 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 17 optional :channels, -> { PreludeSDK::Internal::Type::ArrayOf[enum: PreludeSDK::Verification::Phone::HistoryListParams::Channel] } |
#cursor ⇒ String?
Pagination cursor from the previous response.
24 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 24 optional :cursor, String |
#device_platform ⇒ Symbol, ...
Only verifications created from this device platform.
30 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 30 optional :device_platform, enum: -> { PreludeSDK::Verification::Phone::HistoryListParams::DevicePlatform } |
#from ⇒ Time?
Only verifications created at or after this RFC 3339 timestamp. Goes with to,
at most 6 months apart. Without them the whole history is searched.
37 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 37 optional :from, Time |
#limit ⇒ Integer?
Maximum number of verifications to return per page.
43 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 43 optional :limit, Integer |
#max_attempts ⇒ Integer?
Only verifications that sent at most this many messages. 0 keeps the
verifications that never sent one.
50 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 50 optional :max_attempts, Integer |
#min_attempts ⇒ Integer?
Only verifications that sent at least this many messages.
56 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 56 optional :min_attempts, Integer |
#phone_number ⇒ String?
Only verifications targeting this E.164 phone number. The leading + may be
omitted.
63 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 63 optional :phone_number, String |
#region ⇒ String?
Only verifications of phone numbers from this region, as an ISO 3166-1 alpha-2 code.
70 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 70 optional :region, String |
#status ⇒ Symbol, ...
Only verifications in this status. pending_check cannot be filtered on.
76 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 76 optional :status, enum: -> { PreludeSDK::Verification::Phone::HistoryListParams::Status } |
#template_id ⇒ String?
Only verifications sent with this template, as returned in template_id by
Get a phone verification.
Built-in templates (prelude:*) cannot be filtered on.
84 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 84 optional :template_id, String |
#to ⇒ Time?
Only verifications created at or before this RFC 3339 timestamp. Goes with
from.
91 |
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 91 optional :to, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/verification/phone/history_list_params.rb', line 135
|
Instance Method Details
#to_hash ⇒ {
96 |
# File 'sig/prelude_sdk/models/verification/phone/history_list_params.rbs', line 96
def to_hash: -> {
|