Class: PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check
- Defined in:
- lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb,
sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs
Overview
Defined Under Namespace
Modules: Channel, StatusDetail Classes: Psd2Info
Instance Attribute Summary collapse
- #channel ⇒ Symbol, ...
- #created_at ⇒ Time
- #is_valid ⇒ Boolean
-
#psd2_info ⇒ PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check::Psd2Info?
Present on checks against a
prelude:psd2code. -
#status_detail ⇒ Symbol, ...
Why an invalid check failed, when known.
-
#value ⇒ String?
The submitted code.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(expected_transaction: nil, received_transaction: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Psd2Info for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(expected_transaction: nil, received_transaction: nil) ⇒ Object
Some parameter documentations has been truncated, see Psd2Info for more details.
Present on checks against a prelude:psd2 code.
|
|
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 662
|
Instance Attribute Details
#channel ⇒ Symbol, ...
637 638 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 637 optional :channel, enum: -> { PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check::Channel } |
#created_at ⇒ Time
627 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 627 required :created_at, Time |
#is_valid ⇒ Boolean
632 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 632 required :is_valid, PreludeSDK::Internal::Type::Boolean |
#psd2_info ⇒ PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check::Psd2Info?
Present on checks against a prelude:psd2 code.
644 645 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 644 optional :psd2_info, -> { PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check::Psd2Info } |
#status_detail ⇒ Symbol, ...
Why an invalid check failed, when known.
651 652 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 651 optional :status_detail, enum: -> { PreludeSDK::Models::Verification::Phone::HistoryRetrieveResponse::Lifecycle::Event::Check::StatusDetail } |
#value ⇒ String?
The submitted code. Absent while the verification can still be completed, so that a check in flight cannot be read back through this endpoint, and absent on silent verification checks, which carry no code.
660 |
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 660 optional :value, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/verification/phone/history_retrieve_response.rb', line 694
|
Instance Method Details
#to_hash ⇒ {
632 |
# File 'sig/prelude_sdk/models/verification/phone/history_retrieve_response.rbs', line 632
def to_hash: -> {
|