Class: PreludeSDK::Models::VerificationCheckParams::Psd2
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCheckParams::Psd2
- Defined in:
- lib/prelude_sdk/models/verification_check_params.rb,
sig/prelude_sdk/models/verification_check_params.rbs
Instance Attribute Summary collapse
-
#amount ⇒ String
Decimal amount of the transaction.
-
#currency ⇒ String
ISO 4217 currency code.
-
#recipient ⇒ String
Payee name displayed to the payer.
Instance Method Summary collapse
-
#initialize(amount:, currency:, recipient:) ⇒ Object
constructor
Required when checking a code issued under the
prelude:psd2template. - #to_hash ⇒ { amount: String, currency: String, recipient: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:, recipient:) ⇒ Object
Required when checking a code issued under the prelude:psd2 template. The
submitted variables must match those provided at issuance; any mismatch
invalidates the code (PSD2 SCA RTS Article 5 dynamic linking). Ignored on
non-PSD2 verifications.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 44 class Psd2 < PreludeSDK::Internal::Type::BaseModel # @!attribute amount # Decimal amount of the transaction. # # @return [String] required :amount, String # @!attribute currency # ISO 4217 currency code. # # @return [String] required :currency, String # @!attribute recipient # Payee name displayed to the payer. # # @return [String] required :recipient, String # @!method initialize(amount:, currency:, recipient:) # Required when checking a code issued under the `prelude:psd2` template. The # submitted variables must match those provided at issuance; any mismatch # invalidates the code (PSD2 SCA RTS Article 5 dynamic linking). Ignored on # non-PSD2 verifications. # # @param amount [String] Decimal amount of the transaction. # # @param currency [String] ISO 4217 currency code. # # @param recipient [String] Payee name displayed to the payer. end |
Instance Attribute Details
#amount ⇒ String
Decimal amount of the transaction.
49 |
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 49 required :amount, String |
#currency ⇒ String
ISO 4217 currency code.
55 |
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 55 required :currency, String |
#recipient ⇒ String
Payee name displayed to the payer.
61 |
# File 'lib/prelude_sdk/models/verification_check_params.rb', line 61 required :recipient, String |
Instance Method Details
#to_hash ⇒ { amount: String, currency: String, recipient: String }
54 |
# File 'sig/prelude_sdk/models/verification_check_params.rbs', line 54
def to_hash: -> { amount: String, currency: String, recipient: String }
|