Class: PreludeSDK::Models::VerificationCheckResponse::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCheckResponse::Metadata
- Defined in:
- lib/prelude_sdk/models/verification_check_response.rb
Overview
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
A user-defined identifier to correlate this verification with.
Instance Method Summary collapse
-
#initialize(correlation_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(correlation_id: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationCheckResponse::Metadata for more details.
The metadata for this verification.
|
|
# File 'lib/prelude_sdk/models/verification_check_response.rb', line 62
|
Instance Attribute Details
#correlation_id ⇒ String?
A user-defined identifier to correlate this verification with. It is returned in the response and any webhook events that refer to this verification.
60 |
# File 'lib/prelude_sdk/models/verification_check_response.rb', line 60 optional :correlation_id, String |