Class: PreludeSDK::Models::VerificationCreateParams::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCreateParams::Metadata
- Defined in:
- lib/prelude_sdk/models/verification_create_params.rb,
sig/prelude_sdk/models/verification_create_params.rbs
Instance Attribute Summary collapse
-
#correlation_id ⇒ String?
A user-defined identifier to correlate this verification with.
Instance Method Summary collapse
-
#initialize(target:, dispatch_id: nil, metadata: nil, options: nil, signals: nil, request_options: {}) ⇒ Metadata
constructor
Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationCreateParams for more details.
- #to_hash ⇒ { correlation_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(target:, dispatch_id: nil, metadata: nil, options: nil, signals: nil, request_options: {}) ⇒ Metadata
Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationCreateParams for more details.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 59 class Metadata < PreludeSDK::Internal::Type::BaseModel # @!attribute correlation_id # A user-defined identifier to correlate this verification with. It is returned in # the response and any webhook events that refer to this verification. # # @return [String, nil] optional :correlation_id, String # @!method initialize(correlation_id: nil) # Some parameter documentations has been truncated, see # {PreludeSDK::Models::VerificationCreateParams::Metadata} for more details. # # The metadata for this verification. This object will be returned with every # response or webhook sent that refers to this verification. # # @param correlation_id [String] A user-defined identifier to correlate this verification with. It is returned in end |
Instance Attribute Details
#correlation_id ⇒ String?
A user-defined identifier to correlate this verification with. It is returned in the response and any webhook events that refer to this verification.
65 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 65 optional :correlation_id, String |
Instance Method Details
#to_hash ⇒ { correlation_id: String }
66 |
# File 'sig/prelude_sdk/models/verification_create_params.rbs', line 66
def to_hash: -> { correlation_id: String }
|