Class: PreludeSDK::Models::VerificationCreateParams::Options

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/prelude_sdk/models/verification_create_params.rb

Defined Under Namespace

Modules: Method, PreferredChannel Classes: AppRealm

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app_realm: nil, callback_url: nil, code_size: nil, custom_code: nil, locale: nil, verification_method: nil, preferred_channel: nil, sender_id: nil, template_id: nil, variables: nil) ⇒ Object

Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationCreateParams::Options for more details.

Verification options

Parameters:

  • app_realm (PreludeSDK::Models::VerificationCreateParams::Options::AppRealm) (defaults to: nil)

    This allows automatic OTP retrieval on mobile apps and web browsers. Supported p

  • callback_url (String) (defaults to: nil)

    The URL where webhooks will be sent when verification events occur, including ve

  • code_size (Integer) (defaults to: nil)

    The size of the code generated. It should be between 4 and 8. Defaults to the co

  • custom_code (String) (defaults to: nil)

    The custom code to use for OTP verification. To use the custom code feature, con

  • locale (String) (defaults to: nil)

    A BCP-47 formatted locale string with the language the text message will be sent

  • verification_method (Symbol, PreludeSDK::Models::VerificationCreateParams::Options::Method) (defaults to: nil)

    The method used for verifying this phone number. The ‘voice’ option provides an

  • preferred_channel (Symbol, PreludeSDK::Models::VerificationCreateParams::Options::PreferredChannel) (defaults to: nil)

    The preferred channel to be used in priority for verification.

  • sender_id (String) (defaults to: nil)

    The Sender ID to use for this message. The Sender ID needs to be enabled by Prel

  • template_id (String) (defaults to: nil)

    The identifier of a verification template. It applies use case-specific settings

  • variables (Hash{Symbol=>String}) (defaults to: nil)

    The variables to be replaced in the template.



# File 'lib/prelude_sdk/models/verification_create_params.rb', line 192

Instance Attribute Details

#app_realmPreludeSDK::Models::VerificationCreateParams::Options::AppRealm?

This allows automatic OTP retrieval on mobile apps and web browsers. Supported platforms are Android (SMS Retriever API) and Web (WebOTP API).



118
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 118

optional :app_realm, -> { PreludeSDK::VerificationCreateParams::Options::AppRealm }

#callback_urlString?

The URL where webhooks will be sent when verification events occur, including verification creation, attempt creation, and delivery status changes. For more details, refer to [Webhook](/verify/v2/documentation/webhook).

Returns:

  • (String, nil)


126
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 126

optional :callback_url, String

#code_sizeInteger?

The size of the code generated. It should be between 4 and 8. Defaults to the code size specified from the Dashboard.

Returns:

  • (Integer, nil)


133
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 133

optional :code_size, Integer

#custom_codeString?

The custom code to use for OTP verification. To use the custom code feature, contact us to enable it for your account. For more details, refer to [Custom Code](/verify/v2/documentation/custom-codes).

Returns:

  • (String, nil)


141
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 141

optional :custom_code, String

#localeString?

A BCP-47 formatted locale string with the language the text message will be sent to. If there’s no locale set, the language will be determined by the country code of the phone number. If the language specified doesn’t exist, it defaults to US English.

Returns:

  • (String, nil)


150
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 150

optional :locale, String

#preferred_channelSymbol, ...

The preferred channel to be used in priority for verification.



170
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 170

optional :preferred_channel, enum: -> { PreludeSDK::VerificationCreateParams::Options::PreferredChannel }

#sender_idString?

The Sender ID to use for this message. The Sender ID needs to be enabled by Prelude.

Returns:

  • (String, nil)


177
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 177

optional :sender_id, String

#template_idString?

The identifier of a verification template. It applies use case-specific settings, such as the message content or certain verification parameters.

Returns:

  • (String, nil)


184
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 184

optional :template_id, String

#variablesHash{Symbol=>String}?

The variables to be replaced in the template.

Returns:

  • (Hash{Symbol=>String}, nil)


190
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 190

optional :variables, PreludeSDK::Internal::Type::HashOf[String]

#verification_methodSymbol, ...

The method used for verifying this phone number. The ‘voice’ option provides an accessible alternative for visually impaired users by delivering the verification code through a phone call rather than a text message. It also allows verification of landline numbers that cannot receive SMS messages. The ‘message’ option explicitly requests message delivery (SMS, WhatsApp …) and skips silent verification, useful for scenarios requiring direct user interaction.



162
163
164
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 162

optional :verification_method,
enum: -> { PreludeSDK::VerificationCreateParams::Options::Method },
api_name: :method

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/prelude_sdk/models/verification_create_params.rb', line 260