Class: PreludeSDK::Models::VerificationCreateParams::Options
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCreateParams::Options
- Defined in:
- lib/prelude_sdk/models/verification_create_params.rb
Defined Under Namespace
Modules: Integration, Method, PreferredChannel Classes: AppRealm
Instance Attribute Summary collapse
-
#app_realm ⇒ PreludeSDK::Models::VerificationCreateParams::Options::AppRealm?
This allows you to automatically retrieve and fill the OTP code on mobile apps.
-
#callback_url ⇒ String?
The URL where webhooks will be sent when verification events occur, including verification creation, attempt creation, and delivery status changes.
-
#code_size ⇒ Integer?
The size of the code generated.
-
#custom_code ⇒ String?
The custom code to use for OTP verification.
-
#integration ⇒ Symbol, ...
The integration that triggered the verification.
-
#locale ⇒ String?
A BCP-47 formatted locale string with the language the text message will be sent to.
-
#preferred_channel ⇒ Symbol, ...
The preferred channel to be used in priority for verification.
-
#sender_id ⇒ String?
The Sender ID to use for this message.
-
#template_id ⇒ String?
The identifier of a verification template.
-
#variables ⇒ Hash{Symbol=>String}?
The variables to be replaced in the template.
-
#verification_method ⇒ Symbol, ...
The method used for verifying this phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(app_realm: nil, callback_url: nil, code_size: nil, custom_code: nil, integration: nil, locale: nil, verification_method: nil, preferred_channel: nil, sender_id: nil, template_id: nil, variables: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Options for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_realm: nil, callback_url: nil, code_size: nil, custom_code: nil, integration: nil, locale: nil, verification_method: nil, preferred_channel: nil, sender_id: nil, template_id: nil, variables: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationCreateParams::Options for more details.
Verification options
|
|
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 198
|
Instance Attribute Details
#app_realm ⇒ PreludeSDK::Models::VerificationCreateParams::Options::AppRealm?
This allows you to automatically retrieve and fill the OTP code on mobile apps. Currently only Android devices are supported.
118 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 118 optional :app_realm, -> { PreludeSDK::VerificationCreateParams::Options::AppRealm } |
#callback_url ⇒ String?
The URL where webhooks will be sent when verification events occur, including verification creation, attempt creation, and delivery status changes. For more details, refer to [Webhook](/verify/v2/documentation/webhook).
126 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 126 optional :callback_url, String |
#code_size ⇒ Integer?
The size of the code generated. It should be between 4 and 8. Defaults to the code size specified from the Dashboard.
133 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 133 optional :code_size, Integer |
#custom_code ⇒ String?
The custom code to use for OTP verification. To use the custom code feature, contact us to enable it for your account. For more details, refer to [Custom Code](/verify/v2/documentation/custom-codes).
141 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 141 optional :custom_code, String |
#integration ⇒ Symbol, ...
The integration that triggered the verification.
147 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 147 optional :integration, enum: -> { PreludeSDK::VerificationCreateParams::Options::Integration } |
#locale ⇒ String?
A BCP-47 formatted locale string with the language the text message will be sent to. If there’s no locale set, the language will be determined by the country code of the phone number. If the language specified doesn’t exist, it defaults to US English.
156 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 156 optional :locale, String |
#preferred_channel ⇒ Symbol, ...
The preferred channel to be used in priority for verification.
176 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 176 optional :preferred_channel, enum: -> { PreludeSDK::VerificationCreateParams::Options::PreferredChannel } |
#sender_id ⇒ String?
The Sender ID to use for this message. The Sender ID needs to be enabled by Prelude.
183 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 183 optional :sender_id, String |
#template_id ⇒ String?
The identifier of a verification template. It applies use case-specific settings, such as the message content or certain verification parameters.
190 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 190 optional :template_id, String |
#variables ⇒ Hash{Symbol=>String}?
The variables to be replaced in the template.
196 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 196 optional :variables, PreludeSDK::Internal::Type::HashOf[String] |
#verification_method ⇒ Symbol, ...
The method used for verifying this phone number. The ‘voice’ option provides an accessible alternative for visually impaired users by delivering the verification code through a phone call rather than a text message. It also allows verification of landline numbers that cannot receive SMS messages. The ‘message’ option explicitly requests message delivery (SMS, WhatsApp …) and skips silent verification, useful for scenarios requiring direct user interaction.
168 169 170 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 168 optional :verification_method, enum: -> { PreludeSDK::VerificationCreateParams::Options::Method }, api_name: :method |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 264
|