Module: PreludeSDK::Models::VerificationCreateParams::Options::Method

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/verification_create_params.rb

Overview

The method used for verifying this phone number. The ‘voice’ option provides an accessible alternative for visually impaired users by delivering the verification code through a phone call rather than a text message. It also allows verification of landline numbers that cannot receive SMS messages. The ‘message’ option explicitly requests message delivery (SMS, WhatsApp …) and skips silent verification, useful for scenarios requiring direct user interaction.

Constant Summary collapse

AUTO =
:auto
VOICE =
:voice
MESSAGE =
:message

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info