Class: PreludeSDK::Models::VerificationCreateParams::Signals
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCreateParams::Signals
- Defined in:
- lib/prelude_sdk/models/verification_create_params.rb
Defined Under Namespace
Modules: DevicePlatform
Instance Attribute Summary collapse
-
#app_version ⇒ String?
The version of your application.
-
#device_id ⇒ String?
A unique ID for the user’s device.
-
#device_model ⇒ String?
The model of the user’s device.
-
#device_platform ⇒ Symbol, ...
The type of the user’s device.
-
#ip ⇒ String?
The public IP v4 or v6 address of the end-user’s device.
-
#is_trusted_user ⇒ Boolean?
This signal should indicate a higher level of trust, explicitly stating that the user is genuine.
-
#ja4_fingerprint ⇒ String?
The JA4 fingerprint observed for the end-user’s connection.
-
#os_version ⇒ String?
The version of the user’s device operating system.
-
#user_agent ⇒ String?
The user agent of the user’s device.
Instance Method Summary collapse
-
#initialize(app_version: nil, device_id: nil, device_model: nil, device_platform: nil, ip: nil, is_trusted_user: nil, ja4_fingerprint: nil, os_version: nil, user_agent: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Signals for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_version: nil, device_id: nil, device_model: nil, device_platform: nil, ip: nil, is_trusted_user: nil, ja4_fingerprint: nil, os_version: nil, user_agent: nil) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::VerificationCreateParams::Signals for more details.
The signals used for anti-fraud. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).
|
|
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 369
|
Instance Attribute Details
#app_version ⇒ String?
The version of your application.
308 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 308 optional :app_version, String |
#device_id ⇒ String?
A unique ID for the user’s device. You should ensure that each user device has a unique ‘device_id` value. Ideally, for Android, this corresponds to the `ANDROID_ID` and for iOS, this corresponds to the `identifierForVendor`.
316 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 316 optional :device_id, String |
#device_model ⇒ String?
The model of the user’s device.
322 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 322 optional :device_model, String |
#device_platform ⇒ Symbol, ...
The type of the user’s device.
328 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 328 optional :device_platform, enum: -> { PreludeSDK::VerificationCreateParams::Signals::DevicePlatform } |
#ip ⇒ String?
The public IP v4 or v6 address of the end-user’s device. You should collect this from your backend. If your backend is behind a proxy, use the ‘X-Forwarded-For`, `Forwarded`, `True-Client-IP`, `CF-Connecting-IP` or an equivalent header to get the actual public IP of the end-user’s device.
337 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 337 optional :ip, String |
#is_trusted_user ⇒ Boolean?
This signal should indicate a higher level of trust, explicitly stating that the user is genuine. Contact us to discuss your use case. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).
345 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 345 optional :is_trusted_user, PreludeSDK::Internal::Type::Boolean |
#ja4_fingerprint ⇒ String?
The JA4 fingerprint observed for the end-user’s connection. Prelude will infer it automatically when you use our Frontend SDKs (which use Prelude’s edge network), but you can also forward the value if you terminate TLS yourself.
353 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 353 optional :ja4_fingerprint, String |
#os_version ⇒ String?
The version of the user’s device operating system.
359 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 359 optional :os_version, String |
#user_agent ⇒ String?
The user agent of the user’s device. If the individual fields (os_version, device_platform, device_model) are provided, we will prioritize those values instead of parsing them from the user agent string.
367 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 367 optional :user_agent, String |