Class: PreludeSDK::Models::VerificationCreateParams::Target
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCreateParams::Target
- Defined in:
- lib/prelude_sdk/models/verification_create_params.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#type ⇒ Symbol, PreludeSDK::Models::VerificationCreateParams::Target::Type
The type of the target.
-
#value ⇒ String
An E.164 formatted phone number or an email address.
Instance Method Summary collapse
-
#initialize(type:, value:) ⇒ Object
constructor
The verification target.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, value:) ⇒ Object
The verification target. Either a phone number or an email address. To use the email verification feature contact us to discuss your use case.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 59 class Target < PreludeSDK::Internal::Type::BaseModel # @!attribute type # The type of the target. Either "phone_number" or "email_address". # # @return [Symbol, PreludeSDK::Models::VerificationCreateParams::Target::Type] required :type, enum: -> { PreludeSDK::VerificationCreateParams::Target::Type } # @!attribute value # An E.164 formatted phone number or an email address. # # @return [String] required :value, String # @!method initialize(type:, value:) # The verification target. Either a phone number or an email address. To use the # email verification feature contact us to discuss your use case. # # @param type [Symbol, PreludeSDK::Models::VerificationCreateParams::Target::Type] The type of the target. Either "phone_number" or "email_address". # # @param value [String] An E.164 formatted phone number or an email address. # The type of the target. Either "phone_number" or "email_address". # # @see PreludeSDK::Models::VerificationCreateParams::Target#type module Type extend PreludeSDK::Internal::Type::Enum PHONE_NUMBER = :phone_number EMAIL_ADDRESS = :email_address # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#type ⇒ Symbol, PreludeSDK::Models::VerificationCreateParams::Target::Type
The type of the target. Either “phone_number” or “email_address”.
64 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 64 required :type, enum: -> { PreludeSDK::VerificationCreateParams::Target::Type } |
#value ⇒ String
An E.164 formatted phone number or an email address.
70 |
# File 'lib/prelude_sdk/models/verification_create_params.rb', line 70 required :value, String |