Class: PreludeSDK::Models::VerificationCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationCreateResponse
- Defined in:
- lib/prelude_sdk/models/verification_create_response.rb
Overview
Defined Under Namespace
Modules: Channel, Method, Reason, RiskFactor, Status Classes: Metadata, Silent
Instance Attribute Summary collapse
-
#channels ⇒ Array<Symbol, PreludeSDK::Models::VerificationCreateResponse::Channel>?
The ordered sequence of channels to be used for verification.
-
#id ⇒ String
The verification identifier.
-
#metadata ⇒ PreludeSDK::Models::VerificationCreateResponse::Metadata?
The metadata for this verification.
-
#reason ⇒ Symbol, ...
The reason why the verification was blocked.
- #request_id ⇒ String?
-
#risk_factors ⇒ Array<Symbol, PreludeSDK::Models::VerificationCreateResponse::RiskFactor>?
The risk factors that contributed to the verification being blocked.
-
#silent ⇒ PreludeSDK::Models::VerificationCreateResponse::Silent?
The silent verification specific properties.
-
#status ⇒ Symbol, PreludeSDK::Models::VerificationCreateResponse::Status
The status of the verification.
-
#verification_method ⇒ Symbol, PreludeSDK::Models::VerificationCreateResponse::Method
The method used for verifying this phone number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(correlation_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(correlation_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Metadata for more details.
The metadata for this verification.
|
|
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 108
|
Instance Attribute Details
#channels ⇒ Array<Symbol, PreludeSDK::Models::VerificationCreateResponse::Channel>?
The ordered sequence of channels to be used for verification
38 39 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 38 optional :channels, -> { PreludeSDK::Internal::Type::ArrayOf[enum: PreludeSDK::Models::VerificationCreateResponse::Channel] } |
#id ⇒ String
The verification identifier.
11 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 11 required :id, String |
#metadata ⇒ PreludeSDK::Models::VerificationCreateResponse::Metadata?
The metadata for this verification.
45 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 45 optional :metadata, -> { PreludeSDK::Models::VerificationCreateResponse::Metadata } |
#reason ⇒ Symbol, ...
The reason why the verification was blocked. Only present when status is “blocked”.
-
‘expired_signature` - The signature of the SDK signals is expired. They should be sent within the hour following their collection.
-
‘in_block_list` - The phone number is part of the configured block list.
-
‘invalid_phone_line` - The phone number is not a valid line number (e.g. landline).
-
‘invalid_phone_number` - The phone number is not a valid phone number (e.g. unallocated range).
-
‘invalid_signature` - The signature of the SDK signals is invalid.
-
‘repeated_attempts` - The phone number has made too many verification attempts.
-
‘suspicious` - The verification attempt was deemed suspicious by the anti-fraud system.
65 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 65 optional :reason, enum: -> { PreludeSDK::Models::VerificationCreateResponse::Reason } |
#request_id ⇒ String?
70 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 70 optional :request_id, String |
#risk_factors ⇒ Array<Symbol, PreludeSDK::Models::VerificationCreateResponse::RiskFactor>?
The risk factors that contributed to the verification being blocked. Only present when status is “blocked” and the anti-fraud system detected specific risk signals.
-
‘behavioral_pattern` - The phone number past behavior during verification flows exhibits suspicious patterns.
-
‘device_attribute` - The device exhibits characteristics associated with suspicious activity patterns.
-
‘fraud_database` - The phone number has been flagged as suspicious in one or more of our fraud databases.
-
‘location_discrepancy` - The phone number prefix and IP address discrepancy indicates potential fraud.
-
‘network_fingerprint` - The network connection exhibits characteristics associated with suspicious activity patterns.
-
‘poor_conversion_history` - The phone number has a history of poorly converting to a verified phone number.
-
‘prefix_concentration` - The phone number is part of a range known to be associated with suspicious activity patterns.
-
‘suspected_request_tampering` - The SDK signature is invalid and the request is considered to be tampered with.
-
‘suspicious_ip_address` - The IP address is deemed to be associated with suspicious activity patterns.
-
‘temporary_phone_number` - The phone number is known to be a temporary or disposable number.
99 100 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 99 optional :risk_factors, -> { PreludeSDK::Internal::Type::ArrayOf[enum: PreludeSDK::Models::VerificationCreateResponse::RiskFactor] } |
#silent ⇒ PreludeSDK::Models::VerificationCreateResponse::Silent?
The silent verification specific properties.
106 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 106 optional :silent, -> { PreludeSDK::Models::VerificationCreateResponse::Silent } |
#status ⇒ Symbol, PreludeSDK::Models::VerificationCreateResponse::Status
The status of the verification.
-
‘success` - A new verification window was created.
-
‘retry` - A new attempt was created for an existing verification window.
-
‘challenged` - The verification is suspicious and is restricted to non-SMS and non-voice channels only. This mode must be enabled for your customer account by Prelude support.
-
‘blocked` - The verification was blocked.
32 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 32 required :status, enum: -> { PreludeSDK::Models::VerificationCreateResponse::Status } |
#verification_method ⇒ Symbol, PreludeSDK::Models::VerificationCreateResponse::Method
The method used for verifying this phone number.
17 18 19 |
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 17 required :verification_method, enum: -> { PreludeSDK::Models::VerificationCreateResponse::Method }, api_name: :method |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/verification_create_response.rb', line 141
|