Module: PreludeSDK::Models::VerificationCreateResponse::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/prelude_sdk/models/verification_create_response.rb

Overview

The reason why the verification was blocked. Only present when status is “blocked”.

  • ‘expired_signature` - The signature of the SDK signals is expired. They should be sent within the hour following their collection.

  • ‘in_block_list` - The phone number is part of the configured block list.

  • ‘invalid_phone_line` - The phone number is not a valid line number (e.g. landline).

  • ‘invalid_phone_number` - The phone number is not a valid phone number (e.g. unallocated range).

  • ‘invalid_signature` - The signature of the SDK signals is invalid.

  • ‘repeated_attempts` - The phone number has made too many verification attempts.

  • ‘suspicious` - The verification attempt was deemed suspicious by the anti-fraud system.

See Also:

Constant Summary collapse

EXPIRED_SIGNATURE =
:expired_signature
IN_BLOCK_LIST =
:in_block_list
INVALID_PHONE_LINE =
:invalid_phone_line
INVALID_PHONE_NUMBER =
:invalid_phone_number
INVALID_SIGNATURE =
:invalid_signature
REPEATED_ATTEMPTS =
:repeated_attempts
SUSPICIOUS =
:suspicious

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info