Module: PreludeSDK::Models::VerificationCreateResponse::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/prelude_sdk/models/verification_create_response.rb
Overview
The status of the verification.
-
‘success` - A new verification window was created.
-
‘retry` - A new attempt was created for an existing verification window.
-
‘challenged` - The verification is suspicious and is restricted to non-SMS and non-voice channels only. This mode must be enabled for your customer account by Prelude support.
-
‘blocked` - The verification was blocked.
Constant Summary collapse
- SUCCESS =
:success- RETRY =
:retry- CHALLENGED =
:challenged- BLOCKED =
:blocked
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info