Class: PreludeSDK::Models::VerificationManagement::SandboxAddPhoneNumberResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::VerificationManagement::SandboxAddPhoneNumberResponse
- Defined in:
- lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_response.rb,
sig/prelude_sdk/models/verification_management/sandbox_add_phone_number_response.rbs
Overview
Instance Attribute Summary collapse
-
#attempt_code ⇒ String
The fixed attempt code associated with the sandbox phone number.
-
#phone_number ⇒ String
The E.164 formatted phone number that was added to the sandbox list.
Instance Method Summary collapse
-
#initialize(attempt_code:, phone_number:) ⇒ SandboxAddPhoneNumberResponse
constructor
A new instance of SandboxAddPhoneNumberResponse.
- #to_hash ⇒ { attempt_code: String, phone_number: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attempt_code:, phone_number:) ⇒ SandboxAddPhoneNumberResponse
Returns a new instance of SandboxAddPhoneNumberResponse.
|
|
# File 'lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_response.rb', line 20
|
Instance Attribute Details
#attempt_code ⇒ String
The fixed attempt code associated with the sandbox phone number.
12 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_response.rb', line 12 required :attempt_code, String |
#phone_number ⇒ String
The E.164 formatted phone number that was added to the sandbox list.
18 |
# File 'lib/prelude_sdk/models/verification_management/sandbox_add_phone_number_response.rb', line 18 required :phone_number, String |
Instance Method Details
#to_hash ⇒ { attempt_code: String, phone_number: String }
14 |
# File 'sig/prelude_sdk/models/verification_management/sandbox_add_phone_number_response.rbs', line 14
def to_hash: -> { attempt_code: String, phone_number: String }
|