Class: PreludeSDK::Models::WatchPredictParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/prelude_sdk/models/watch_predict_params.rb

Overview

Defined Under Namespace

Classes: Metadata, Signals, Target

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(correlation_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Metadata for more details.

The metadata for this prediction.

Parameters:

  • correlation_id (String) (defaults to: nil)

    A user-defined identifier to correlate this prediction with. It is returned in t



# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 91

Instance Attribute Details

#dispatch_idString?

The identifier of the dispatch that came from the front-end SDK.

Returns:

  • (String, nil)


20
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 20

optional :dispatch_id, String

#metadataPreludeSDK::Models::WatchPredictParams::Metadata?

The metadata for this prediction.



26
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 26

optional :metadata, -> { PreludeSDK::WatchPredictParams::Metadata }

#signalsPreludeSDK::Models::WatchPredictParams::Signals?

The signals used for anti-fraud. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).



33
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 33

optional :signals, -> { PreludeSDK::WatchPredictParams::Signals }

#targetPreludeSDK::Models::WatchPredictParams::Target

The prediction target. Only supports phone numbers for now.



14
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 14

required :target, -> { PreludeSDK::WatchPredictParams::Target }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 78