Class: PreludeSDK::Models::WatchPredictParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::WatchPredictParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/prelude_sdk/models/watch_predict_params.rb
Overview
Defined Under Namespace
Classes: Metadata, Signals, Target
Instance Attribute Summary collapse
-
#dispatch_id ⇒ String?
The identifier of the dispatch that came from the front-end SDK.
-
#metadata ⇒ PreludeSDK::Models::WatchPredictParams::Metadata?
The metadata for this prediction.
-
#signals ⇒ PreludeSDK::Models::WatchPredictParams::Signals?
The signals used for anti-fraud.
-
#target ⇒ PreludeSDK::Models::WatchPredictParams::Target
The prediction target.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(correlation_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Metadata for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(correlation_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Metadata for more details.
The metadata for this prediction.
|
|
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 91
|
Instance Attribute Details
#dispatch_id ⇒ String?
The identifier of the dispatch that came from the front-end SDK.
20 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 20 optional :dispatch_id, String |
#metadata ⇒ PreludeSDK::Models::WatchPredictParams::Metadata?
The metadata for this prediction.
26 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 26 optional :metadata, -> { PreludeSDK::WatchPredictParams::Metadata } |
#signals ⇒ PreludeSDK::Models::WatchPredictParams::Signals?
The signals used for anti-fraud. For more details, refer to [Signals](/verify/v2/documentation/prevent-fraud#signals).
33 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 33 optional :signals, -> { PreludeSDK::WatchPredictParams::Signals } |
#target ⇒ PreludeSDK::Models::WatchPredictParams::Target
The prediction target. Only supports phone numbers for now.
14 |
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 14 required :target, -> { PreludeSDK::WatchPredictParams::Target } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/watch_predict_params.rb', line 78
|