Class: PreludeSDK::Models::WatchSendEventsParams::Event
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- PreludeSDK::Models::WatchSendEventsParams::Event
- Defined in:
- lib/prelude_sdk/models/watch_send_events_params.rb,
sig/prelude_sdk/models/watch_send_events_params.rbs
Defined Under Namespace
Modules: Confidence Classes: Target
Instance Attribute Summary collapse
-
#confidence ⇒ Symbol, PreludeSDK::Models::WatchSendEventsParams::Event::Confidence
How much this event tells us to trust the end-user's legitimacy — not how certain you are that the event occurred.
-
#label ⇒ String
A label to describe what the event refers to.
-
#target ⇒ PreludeSDK::Models::WatchSendEventsParams::Event::Target
The event target.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(confidence:, label:, target:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Event for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(confidence:, label:, target:) ⇒ Object
Some parameter documentations has been truncated, see PreludeSDK::Models::WatchSendEventsParams::Event for more details.
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/prelude_sdk/models/watch_send_events_params.rb', line 25 class Event < PreludeSDK::Internal::Type::BaseModel # @!attribute confidence # How much this event tells us to trust the end-user's legitimacy — not how # certain you are that the event occurred. In increasing order of trust: # `minimum`, `low`, `neutral`, `high`, `maximum`. # # Use `minimum` for an event tied to a user you trust the least to be legitimate # (e.g. a `payment.chargeback`), and `maximum` for an event tied to a highly # trustworthy user (e.g. a confirmed 3DS payment). Prelude weights these signals # when scoring traffic: it filters out users tied to low-confidence events while # preserving the experience for users tied to high-confidence ones. # # @return [Symbol, PreludeSDK::Models::WatchSendEventsParams::Event::Confidence] required :confidence, enum: -> { PreludeSDK::WatchSendEventsParams::Event::Confidence } # @!attribute label # A label to describe what the event refers to. # # @return [String] required :label, String # @!attribute target # The event target. Only supports phone numbers for now. # # @return [PreludeSDK::Models::WatchSendEventsParams::Event::Target] required :target, -> { PreludeSDK::WatchSendEventsParams::Event::Target } # @!method initialize(confidence:, label:, target:) # Some parameter documentations has been truncated, see # {PreludeSDK::Models::WatchSendEventsParams::Event} for more details. # # @param confidence [Symbol, PreludeSDK::Models::WatchSendEventsParams::Event::Confidence] How much this event tells us to trust the end-user's legitimacy — not how certai # # @param label [String] A label to describe what the event refers to. # # @param target [PreludeSDK::Models::WatchSendEventsParams::Event::Target] The event target. Only supports phone numbers for now. # How much this event tells us to trust the end-user's legitimacy — not how # certain you are that the event occurred. In increasing order of trust: # `minimum`, `low`, `neutral`, `high`, `maximum`. # # Use `minimum` for an event tied to a user you trust the least to be legitimate # (e.g. a `payment.chargeback`), and `maximum` for an event tied to a highly # trustworthy user (e.g. a confirmed 3DS payment). Prelude weights these signals # when scoring traffic: it filters out users tied to low-confidence events while # preserving the experience for users tied to high-confidence ones. # # @see PreludeSDK::Models::WatchSendEventsParams::Event#confidence module Confidence extend PreludeSDK::Internal::Type::Enum MAXIMUM = :maximum HIGH = :high NEUTRAL = :neutral LOW = :low MINIMUM = :minimum # @!method self.values # @return [Array<Symbol>] end # @see PreludeSDK::Models::WatchSendEventsParams::Event#target class Target < PreludeSDK::Internal::Type::BaseModel # @!attribute type # The type of the target. Either "phone_number" or "email_address". # # @return [Symbol, PreludeSDK::Models::WatchSendEventsParams::Event::Target::Type] required :type, enum: -> { PreludeSDK::WatchSendEventsParams::Event::Target::Type } # @!attribute value # An E.164 formatted phone number or an email address. # # @return [String] required :value, String # @!method initialize(type:, value:) # The event target. Only supports phone numbers for now. # # @param type [Symbol, PreludeSDK::Models::WatchSendEventsParams::Event::Target::Type] The type of the target. Either "phone_number" or "email_address". # # @param value [String] An E.164 formatted phone number or an email address. # The type of the target. Either "phone_number" or "email_address". # # @see PreludeSDK::Models::WatchSendEventsParams::Event::Target#type module Type extend PreludeSDK::Internal::Type::Enum PHONE_NUMBER = :phone_number EMAIL_ADDRESS = :email_address # @!method self.values # @return [Array<Symbol>] end end end |
Instance Attribute Details
#confidence ⇒ Symbol, PreludeSDK::Models::WatchSendEventsParams::Event::Confidence
How much this event tells us to trust the end-user's legitimacy — not how
certain you are that the event occurred. In increasing order of trust:
minimum, low, neutral, high, maximum.
Use minimum for an event tied to a user you trust the least to be legitimate
(e.g. a payment.chargeback), and maximum for an event tied to a highly
trustworthy user (e.g. a confirmed 3DS payment). Prelude weights these signals
when scoring traffic: it filters out users tied to low-confidence events while
preserving the experience for users tied to high-confidence ones.
38 |
# File 'lib/prelude_sdk/models/watch_send_events_params.rb', line 38 required :confidence, enum: -> { PreludeSDK::WatchSendEventsParams::Event::Confidence } |
#label ⇒ String
A label to describe what the event refers to.
44 |
# File 'lib/prelude_sdk/models/watch_send_events_params.rb', line 44 required :label, String |
#target ⇒ PreludeSDK::Models::WatchSendEventsParams::Event::Target
The event target. Only supports phone numbers for now.
50 |
# File 'lib/prelude_sdk/models/watch_send_events_params.rb', line 50 required :target, -> { PreludeSDK::WatchSendEventsParams::Event::Target } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/prelude_sdk/models/watch_send_events_params.rb', line 82
|
Instance Method Details
#to_hash ⇒ {
43 |
# File 'sig/prelude_sdk/models/watch_send_events_params.rbs', line 43
def to_hash: -> {
|