Module: PreludeSDK::Models::WatchSendEventsParams::Event::Confidence
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/prelude_sdk/models/watch_send_events_params.rb,
sig/prelude_sdk/models/watch_send_events_params.rbs
Overview
How much this event tells us to trust the end-user's legitimacy — not how
certain you are that the event occurred. In increasing order of trust:
minimum, low, neutral, high, maximum.
Use minimum for an event tied to a user you trust the least to be legitimate
(e.g. a payment.chargeback), and maximum for an event tied to a highly
trustworthy user (e.g. a confirmed 3DS payment). Prelude weights these signals
when scoring traffic: it filters out users tied to low-confidence events while
preserving the experience for users tied to high-confidence ones.
Constant Summary collapse
- MAXIMUM =
:maximum- HIGH =
:high- NEUTRAL =
:neutral- LOW =
:low- MINIMUM =
:minimum
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[PreludeSDK::Models::WatchSendEventsParams::Event::confidence]
60 |
# File 'sig/prelude_sdk/models/watch_send_events_params.rbs', line 60
def self?.values: -> ::Array[PreludeSDK::Models::WatchSendEventsParams::Event::confidence]
|