Class: PreludeSDK::Resources::Watch
- Inherits:
-
Object
- Object
- PreludeSDK::Resources::Watch
- Defined in:
- lib/prelude_sdk/resources/watch.rb
Overview
Evaluate email addresses and phone numbers for trustworthiness.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Watch
constructor
private
A new instance of Watch.
-
#predict(target:, dispatch_id: nil, metadata: nil, signals: nil, request_options: {}) ⇒ PreludeSDK::Models::WatchPredictResponse
Some parameter documentations has been truncated, see Models::WatchPredictParams for more details.
-
#send_events(events:, request_options: {}) ⇒ PreludeSDK::Models::WatchSendEventsResponse
Some parameter documentations has been truncated, see Models::WatchSendEventsParams for more details.
-
#send_feedbacks(feedbacks:, request_options: {}) ⇒ PreludeSDK::Models::WatchSendFeedbacksResponse
Some parameter documentations has been truncated, see Models::WatchSendFeedbacksParams for more details.
Constructor Details
#initialize(client:) ⇒ Watch
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Watch.
93 94 95 |
# File 'lib/prelude_sdk/resources/watch.rb', line 93 def initialize(client:) @client = client end |
Instance Method Details
#predict(target:, dispatch_id: nil, metadata: nil, signals: nil, request_options: {}) ⇒ PreludeSDK::Models::WatchPredictResponse
Some parameter documentations has been truncated, see Models::WatchPredictParams for more details.
Predict the outcome of a verification based on Prelude’s anti-fraud system.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/prelude_sdk/resources/watch.rb', line 27 def predict(params) parsed, = PreludeSDK::WatchPredictParams.dump_request(params) @client.request( method: :post, path: "v2/watch/predict", body: parsed, model: PreludeSDK::Models::WatchPredictResponse, options: ) end |
#send_events(events:, request_options: {}) ⇒ PreludeSDK::Models::WatchSendEventsResponse
Some parameter documentations has been truncated, see Models::WatchSendEventsParams for more details.
Send real-time event data from end-user interactions within your application. Events will be analyzed for proactive fraud prevention and risk scoring.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/prelude_sdk/resources/watch.rb', line 53 def send_events(params) parsed, = PreludeSDK::WatchSendEventsParams.dump_request(params) @client.request( method: :post, path: "v2/watch/event", body: parsed, model: PreludeSDK::Models::WatchSendEventsResponse, options: ) end |
#send_feedbacks(feedbacks:, request_options: {}) ⇒ PreludeSDK::Models::WatchSendFeedbacksResponse
Some parameter documentations has been truncated, see Models::WatchSendFeedbacksParams for more details.
Send feedback regarding your end-users verification funnel. Events will be analyzed for proactive fraud prevention and risk scoring.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/prelude_sdk/resources/watch.rb', line 79 def send_feedbacks(params) parsed, = PreludeSDK::WatchSendFeedbacksParams.dump_request(params) @client.request( method: :post, path: "v2/watch/feedback", body: parsed, model: PreludeSDK::Models::WatchSendFeedbacksResponse, options: ) end |